@@ -49,7 +49,7 @@ protected:
   int pHeight_;              // parsed array height
   int pDepth_;               // parsed array depth
   int pBitpix_;              // parsed array bitpix
-  int pSkip_;                // parsed array skip size
+  size_t pSkip_;             // parsed array skip size
   ArchType pArch_;           // parsed array arch type
 
   int pHPXOrder_;             // parsed HPX params
@@ -85,7 +85,7 @@ public:
   virtual ~FitsFile();
 
   virtual void done() {}
-  virtual char* page(char* ptr, off_t r) {return ptr;}
+  virtual char* page(char* ptr, size_t r) {return ptr;}
   virtual void resetpage() {}
   void error(const char*);
   void* data() {return data_;}
@@ -126,7 +126,7 @@ public:
   void setpYdim(int i) {pHeight_ = i;}
   void setpZdim(int i) {pDepth_ = i;}
   void setpBitpix(int b) {pBitpix_ = b;}
-  void setpSkip(int s) {pSkip_ = s;}
+  void setpSkip(size_t s) {pSkip_ = s;}
   void setpArch(ArchType a) {pArch_ = a;}
 
   int pHPXOrder() {return pHPXOrder_;}
