@@ -22,12 +22,12 @@ class FitsHDU {
   int naxes_;                 // NAXIS keyword
   int naxis_[FTY_MAXAXES];    // NAXIS[i] keywords
 
-  off_t realbytes_;      // Number of real bytes
-  off_t heapbytes_;      // Number of heap bytes
-  off_t allbytes_;       // Number of real bytes + heap bytes
-  off_t padbytes_;       // Number of pad bytes
-  off_t databytes_;      // Number of total bytes (padded)
-  off_t datablocks_;     // Number of total blocks
+  size_t realbytes_;      // Number of real bytes
+  size_t heapbytes_;      // Number of heap bytes
+  size_t allbytes_;       // Number of real bytes + heap bytes
+  size_t padbytes_;       // Number of pad bytes
+  size_t databytes_;      // Number of total bytes (padded)
+  size_t datablocks_;     // Number of total blocks
 
   char keybuf[9];
   char* keycat(const char*, int);
@@ -44,17 +44,17 @@ public:
   int naxes() {return naxes_;}
   int naxis(int i) {return i<=naxes_ ? naxis_[i-1] : 0;}
 
-  off_t realbytes() {return realbytes_;}
-  off_t heapbytes() {return heapbytes_;}
-  off_t allbytes() {return allbytes_;}
-  off_t padbytes() {return padbytes_;}
-  off_t databytes() {return databytes_;}
-  off_t datablocks() {return datablocks_;}
+  size_t realbytes() {return realbytes_;}
+  size_t heapbytes() {return heapbytes_;}
+  size_t allbytes() {return allbytes_;}
+  size_t padbytes() {return padbytes_;}
+  size_t databytes() {return databytes_;}
+  size_t datablocks() {return datablocks_;}
 };
 
 class FitsImageHDU : public FitsHDU {
 private:
-  off_t imgbytes_;    // number of image bytes
+  size_t imgbytes_;    // number of image bytes
 
   double bscale_;
   double bzero_;
@@ -66,7 +66,7 @@ public:
 
   void updateCards(FitsHead*);
 
-  off_t imgbytes() {return imgbytes_;}
+  size_t imgbytes() {return imgbytes_;}
   double bscale() {return bscale_;}
   double bzero() {return bzero_;}
   int hasscaling() {return bscale_ != 1 || bzero_ != 0;}
