@@ -19,7 +19,7 @@ class FitsHead {
  private:
   char* cards_; // pointer to start of cards
   char* mapdata_; // pointer to start of memory segment
-  off_t mapsize_; // size of memory segment
+  size_t mapsize_; // size of memory segment
   Memory memory_; // type memory mangement
 
   int ncard_; // actual number of cards
@@ -36,11 +36,10 @@ private:
   void buildIndex();
 
 public:
-  FitsHead(char*, off_t, Memory);
-  FitsHead(char*, off_t, char*, off_t, Memory);
+  FitsHead(char*, size_t, Memory);
+  FitsHead(char*, size_t, char*, size_t, Memory);
   FitsHead(int width, int height, int depth, int bitpix, char* =NULL);
-  FitsHead(int width, int height, int depth, int bitpix, 
-	   char*, off_t, Memory);
+  FitsHead(int width, int height, int depth, int bitpix, char*, size_t, Memory);
   FitsHead(const FitsHead&);
   ~FitsHead();
    
@@ -64,12 +63,12 @@ public:
   int naxes() {return hdu_ ? hdu_->naxes() : 0;}
   int naxis(int i) {return hdu_ ? hdu_->naxis(i) : 0;}
 
-  off_t realbytes() {return hdu_ ? hdu_->realbytes() : 0;}
-  off_t heapbytes() {return hdu_ ? hdu_->heapbytes() : 0;}
-  off_t allbytes() {return hdu_ ? hdu_->allbytes() : 0;}
-  off_t padbytes() {return hdu_ ? hdu_->padbytes() : 0;}
-  off_t databytes() {return hdu_ ? hdu_->databytes() : 0;}
-  off_t datablocks() {return hdu_ ? hdu_->datablocks() : 0;}
+  size_t realbytes() {return hdu_ ? hdu_->realbytes() : 0;}
+  size_t heapbytes() {return hdu_ ? hdu_->heapbytes() : 0;}
+  size_t allbytes() {return hdu_ ? hdu_->allbytes() : 0;}
+  size_t padbytes() {return hdu_ ? hdu_->padbytes() : 0;}
+  size_t databytes() {return hdu_ ? hdu_->databytes() : 0;}
+  size_t datablocks() {return hdu_ ? hdu_->datablocks() : 0;}
 
   void updateHDU();
   void updateCards() {if (hdu_) hdu_->updateCards(this);}
