@@ -10,18 +10,18 @@
 class FitsMap : public FitsFile {
 protected:
   char* mapdata_;
-  off_t mapsize_;
+  size_t mapsize_;
 
 public:
   FitsMap();
   virtual ~FitsMap() {}
 
   char* mapdata() {return mapdata_;}
-  int mapsize() {return mapsize_;}
+  size_t mapsize() {return mapsize_;}
   void found(char*);
   void error();
   char* enddata();
-  int endsize();
+  size_t endsize();
 };
 
 class FitsFitsMap : public virtual FitsMap {
