@@ -5,6 +5,12 @@
 #ifndef __outfits_h__
 #define __outfits_h__
 
+#include <tcl.h>
+
+#include "util.h"
+
+#define STRMREADSIZE 1048576 // 1Mb
+
 class OutFitsStream {
  protected:
   int valid_;
@@ -13,7 +19,7 @@ class OutFitsStream {
   OutFitsStream();
   virtual ~OutFitsStream();
 
-  virtual int write(char*, int) =0;
+  virtual int write(char*, size_t) =0;
   int writeSwap(char*, int, int);
   int valid() {return valid_;}
 };
