@@ -17,7 +17,7 @@ class OutFitsSocket : public virtual OutFitsStream {
  public:
   OutFitsSocket(int s);
 
-  int write(char*, int);
+  int write(char*, size_t);
 };
 
 class OutFitsSocketGZ : public virtual OutFitsStream {
@@ -34,7 +34,7 @@ class OutFitsSocketGZ : public virtual OutFitsStream {
   OutFitsSocketGZ(int);
   ~OutFitsSocketGZ();
 
-  int write(char*, int);
+  int write(char*, size_t);
 };
 
 #endif
