@@ -9,6 +9,7 @@
 #include "zlib.h"
 
 #define GZBUFSIZE 4096
+#define STRMREADSIZE 1048576 // 1Mb
 
 typedef struct gzStream_ {
   z_stream zstream;
@@ -21,18 +22,19 @@ typedef struct gzStream_ {
 
 template<class T>
 class FitsStream : public FitsFile {
-protected:
+ protected:
   T stream_;
-  off_t dataSize_;           // size of data memory segment
+  size_t dataSize_;           // size of data memory segment
   int dataManage_;           // flag, true if we manage data
   FitsFile::FlushMode flush_;
 
   FitsHead* headRead();
-  int dataRead(off_t);
-  void dataSkip(off_t);
+  int dataRead(size_t);
+  void dataSkip(size_t);
+  void dataSkipBlock(size_t);
   void skipEnd();
 
-  int read(char*, off_t);
+  size_t read(char*, size_t);
   void close();
   void found();
   void error();
