@@ -186,8 +186,6 @@ public:
   int pannerWidth;           // panner width
   int pannerHeight;          // panner height
   char pannerName[32];       // panner widget name
-  Coord::CoordSystem pannerSystem;  // panner wcs coord system
-  Coord::SkyFrame pannerSky;        // panner wcs sky frame
   int usePanner;             // panner status
   GC pannerGC;
 
@@ -268,6 +266,8 @@ public:
   XColor* nanColor;
   char nanTrueColor_[4];  // color encoded
 
+  float dlist[2];
+
   char* colorbartag;
 
   Matrix dataToImage;
@@ -367,6 +367,7 @@ public:
 
   virtual int isIIS();
   FitsImage* isInFits(const Vector&, Coord::InternalSystem, Vector*);
+  FitsImage* isInCFits(const Vector&, Coord::InternalSystem, Vector*);
   virtual int isAzElZero() {return 1;}
   virtual int isFrame() {return 0;}
   virtual int isFrame3d() {return 0;}
@@ -374,9 +375,27 @@ public:
 
   void loadDone(int, LayerType);
 
-  int markerAnalysisPlot2d(double**, double**, double**, double**, Marker*,
-			   Vector&, Vector&, int);
-  int markerAnalysisPlot3d(double**, double**, Marker*, const BBox&);
+  int markerAnalysisPlot2d(Marker*, double**, double**, double**, double**,
+			   Vector&, Vector&, int, 
+			   Coord::CoordSystem, Coord::SkyFrame, 
+			   Marker::AnalysisMethod);
+  int markerAnalysisPlot3d(Marker*, double**, double**, const BBox&,
+			   Coord::CoordSystem, Marker::AnalysisMethod);
+  int markerAnalysisRadial(Marker*, double**, double**, double**, 
+			   int, Vector*, BBox*, Coord::CoordSystem);
+  int markerAnalysisPanda(Marker*, double**, double**, double**, 
+			  int, Vector*, int, double*, 
+			  BBox*, Coord::CoordSystem);
+  int markerAnalysisStats1(FitsImage*, ostream&, Coord::CoordSystem);
+  void markerAnalysisStats2(FitsImage*, ostream&, Coord::CoordSystem,
+			    int, int, double, int);
+  void markerAnalysisStats3(ostream&);
+  void markerAnalysisStats4(ostream&, int, int, double, double,	
+			    double, double, double);
+  void markerAnalysisStats(Marker*, ostream&, const BBox&, Coord::CoordSystem);
+  void markerAnalysisStats(Marker*, ostream&, int, BBox*, Coord::CoordSystem);
+  void markerAnalysisStats(Marker*, ostream&, int, int, 
+			   BBox*, Coord::CoordSystem);
 
   double mapDistFromRef(const Vector&, const Vector&, Coord::InternalSystem);
   double mapLenFromRef(double, Coord::InternalSystem);
@@ -416,7 +435,7 @@ public:
   void ps();
   void psContours(PSColorSpace);
   void psCrosshair(PSColorSpace);
-  virtual void psHighlite(PSColorSpace) {}
+  virtual void psGraphics(PSColorSpace) {}
   void psImage(Filter&, PSColorSpace, int, int, float);
   void psMarkers(List<Marker>*, int);
   Matrix psMatrix(float scale, int width, int height);
@@ -425,13 +444,6 @@ public:
   virtual void pushPannerMatrices();
   virtual void pushPSMatrices(float, int, int);
 
-  void renderContours(Pixmap, Coord::InternalSystem, int, int);
-  void renderCrosshair(Pixmap, Coord::InternalSystem, int, int);
-  void renderDash(GC, int);
-  virtual void renderHighlite();
-  void renderMagnifierMarkers(List<Marker>*, const BBox& bb);
-  void renderMarkers(List<Marker>*, const BBox&);
-  void renderMarkerXOR(Marker*);
   virtual void reset();
   void resetScanMode();
 
@@ -458,7 +470,6 @@ public:
   virtual void updateGCs();
   void updateMagnifier();
   void updateMagnifier(const Vector&);
-  virtual void renderMagnifierCursor(const Vector&) =0;
 
   virtual void updateMatrices();
   virtual void updateMagnifierMatrices();
@@ -472,6 +483,14 @@ public:
   char* varcat(char*, char*, char, char*);
   virtual int validColorScale() =0;
 
+  void x11Contours(Pixmap, Coord::InternalSystem, int, int);
+  void x11Crosshair(Pixmap, Coord::InternalSystem, int, int);
+  void x11Dash(GC, int);
+  virtual void x11Graphics();
+  virtual void x11MagnifierCursor(const Vector&) {}
+  void x11MagnifierMarkers(List<Marker>*, const BBox& bb);
+  void x11Markers(List<Marker>*, const BBox&);
+  void x11MarkerXOR(Marker*);
   void xmlParse(istream&);
   void xmlParseFIELD(void*, int*, char**, char**, char**, char**, int);
   void xmlParseTR(char**, int*, char**, char**, char**, char**, int);
@@ -494,7 +513,7 @@ public:
   void macosx();
   void macosxContours();
   void macosxCrosshair();
-  virtual void macosxHighlite() {}
+  virtual void macosxGraphics() {}
   void macosxImage(float, int, int, const Vector&, const Vector&)
   void macosxMarkers(List<Marker>* ml);
 #endif
@@ -502,7 +521,7 @@ public:
   void win32();
   void win32Contours();
   void win32Crosshair();
-  virtual void win32Highlite() {}
+  virtual void win32Graphics() {}
   void win32Image(float, int, int, const Vector&, const Vector&);
   void win32Markers(List<Marker>* ml);
 #endif
@@ -549,6 +568,13 @@ public:
   Coord::CoordSystem xySystem() {return xySystem_;}
   Coord::SkyFrame xySky() {return xySky_;}
 
+  void matchCmd(const char* xxname1, const char* yyname1,
+		Coord::CoordSystem sys1, Coord::SkyFrame sky1,
+		const char* xxname2, const char* yyname2,
+		Coord::CoordSystem sys2, Coord::SkyFrame sky2,
+		double rad, Coord::CoordSystem sys, Coord::SkyDist dist,
+		const char* rr);
+
   // Background Commands
   void bgColorCmd(const char*);
   void getBgColorCmd();
@@ -913,10 +939,12 @@ public:
   void getVertCutCmd(char*, char*, const Vector&, Coord::InternalSystem);
 
   // Grid Commands
-  virtual void gridCmd(Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, Grid::GridType, const char*) =0;
+  virtual void gridCmd(Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, 
+		       Grid::GridType, const char*, const char*) =0;
   void gridDeleteCmd();
   void getGridCmd();
   void getGridOptionCmd();
+  void getGridVarsCmd();
   void hasGridCmd();
 
   // IIS Commands
@@ -1134,13 +1162,19 @@ public:
 
   // Template Regions
   void createTemplateCmd(const Vector&, const char*);
-  void createTemplateCmd(const Vector&, Coord::CoordSystem, Coord::SkyFrame, const char*);
+  void createTemplateCmd(const Vector&, Coord::CoordSystem, Coord::SkyFrame, 
+			 const char*);
   void createTemplateVarCmd(const Vector&, const char* var);
 
-  void getMarkerAnalysisPlot2dCmd(int, char*, char*, char*, char*);
-  void getMarkerAnalysisPlot3dCmd(int, char*, char*);
-  void getMarkerAnalysisParamCmd(int id);
-  void getMarkerAnalysisSystemCmd(int id);
+  void getMarkerAnalysisPlot2dCmd(int, char*, char*, char*, char*, 
+				  Coord::CoordSystem, Coord::SkyFrame, 
+				  Marker::AnalysisMethod);
+  void getMarkerAnalysisPlot3dCmd(int, char*, char*,
+				  Coord::CoordSystem, 
+				  Marker::AnalysisMethod);
+  void getMarkerAnalysisPandaCmd(int, Coord::CoordSystem);
+  void getMarkerAnalysisRadialCmd(int, char*, char*, char*, Coord::CoordSystem);
+  void getMarkerAnalysisStatsCmd(int, Coord::CoordSystem);
 
   void getMarkerAngleCmd(int);
   void getMarkerAngleCmd(int, Coord::CoordSystem, Coord::SkyFrame);
@@ -1250,10 +1284,7 @@ public:
 
   void markerLayerCmd(MarkerLayer);
 
-  void markerAnalysisCmd(int, Marker::AnalysisMethod, int);
-  void markerAnalysisParamCmd(int, Marker::AnalysisParamType);
-  void markerAnalysisSystemCmd(int, Coord::CoordSystem, 
-			       Coord::SkyFrame =Coord::FK5);
+  void markerAnalysisCmd(int, Marker::AnalysisTask, int);
 
   void markerAngleCmd(int, double);
   void markerAngleCmd(int, double, Coord::CoordSystem, Coord::SkyFrame);
@@ -1518,7 +1549,7 @@ public:
   void wcsAlignCmd(int);
   // used by backup
   void wcsAlignCmd(int, Coord::CoordSystem, Coord::SkyFrame);
-  void wcsAlignCmd(int, FitsImage*, Coord::CoordSystem);
+  void wcsAlignCmd(int, FitsImage*, Coord::CoordSystem, Coord::SkyFrame);
   void zoomCmd(const Vector&);
   void zoomToCmd(const Vector&);
   virtual void zoomAboutCmd(const Vector&, const Vector&) =0;
@@ -1532,8 +1563,9 @@ public:
   // Panner Commands
   void pannerCmd(int);
   void pannerCmd(char*, int, int);
-  void pannerCmd(Coord::CoordSystem, Coord::SkyFrame);
   void updatePannerCmd();
+  // backward compatiblity
+  void pannerCmd(Coord::CoordSystem, Coord::SkyFrame) {}
 
   // Pixel Table Commands
   void getPixelTableCmd(const Vector&, Coord::InternalSystem, int, int, char*);
@@ -1586,13 +1618,23 @@ public:
   virtual void setRGBSystemCmd(Coord::CoordSystem) {}
 
   // 3d
+  virtual void get3dBorderCmd() =0;
+  virtual void get3dBorderColorCmd() =0;
+  virtual void get3dCompassCmd() =0;
+  virtual void get3dCompassColorCmd() =0;
   virtual void get3dHighliteCmd() =0;
   virtual void get3dHighliteColorCmd() =0;
+  virtual void get3dScaleCmd() =0;
   virtual void get3dViewCmd() =0;
   virtual void get3dViewPointCmd() =0;
   virtual void get3dRenderMethodCmd() =0;
+  virtual void set3dBorderCmd(int) {}
+  virtual void set3dBorderColorCmd(const char*) {}
+  virtual void set3dCompassCmd(int) {}
+  virtual void set3dCompassColorCmd(const char*) {}
   virtual void set3dHighliteCmd(int) {}
   virtual void set3dHighliteColorCmd(const char*) {}
+  virtual void set3dScaleCmd(double) {}
   virtual void set3dViewCmd(float, float) {}
   virtual void set3dViewPointCmd(const Vector3d&, const Vector&) {}
   virtual void set3dRenderMethodCmd(int) {}
