@@ -5,6 +5,8 @@
 #ifndef __basepanda_h__
 #define __basepanda_h__
 
+#include "vector.h"
+
 class BasePanda {
  protected:
   double *angles_;
@@ -16,6 +18,8 @@ class BasePanda {
   void addAngle(double);
   void deleteAngle(int);
 
+  int isIn(Vector&, int);
+
  public:
   BasePanda(const BasePanda& a);
   BasePanda(double a1, double a2, int an);
