@@ -120,9 +120,9 @@ class FitsImage {
   int smooth();
 
   void wcsShow(WorldCoor*);
-  void astinit(int);
+  void astinit(int, FitsHead*);
   int checkAst(double, double);
-  AstFrameSet* fits2ast();  
+  AstFrameSet* fits2ast(FitsHead*);  
   AstFrameSet* wcs2ast(int);
   void putFitsCard(void* chan, const char* key, const char* value);
   void putFitsCard(void* chan, const char* key, int value);
@@ -225,6 +225,13 @@ class FitsImage {
 
   void close() {if (fits_) fits_->done();}
 
+  void match(const char* xxname1, const char* yyname1,
+	     Coord::CoordSystem sys1, Coord::SkyFrame sky1,
+	     const char* xxname2, const char* yyname2,
+	     Coord::CoordSystem sys2, Coord::SkyFrame sky2,
+	     double rad, Coord::CoordSystem sys, Coord::SkyDist dist,
+	     const char* rrname);
+
   Matrix updateHistCenter();
   Matrix updateHistCursor();
   Matrix updateHist(const Vector&);
@@ -363,7 +370,9 @@ class FitsImage {
   void updatePS(Matrix);
   void updatePS(Matrix3d);
 
+  Matrix& matrixFromData(Coord::InternalSystem);
   Matrix& matrixToData(Coord::InternalSystem);
+  Matrix3d& matrixFromData3d(Coord::InternalSystem);
   Matrix3d& matrixToData3d(Coord::InternalSystem);
 
   Vector mapFromRef(const Vector&, Coord::CoordSystem, Coord::SkyFrame =Coord::FK5);
@@ -419,8 +428,6 @@ class FitsImage {
   char* displayPrimary();
   char* displayWCS();
   FitsHead* getHead();
-  char* getCards();
-  int getNCards();
   char* getKeyword(const char*);
   int findKeyword(const char*);
 
