@@ -37,8 +37,8 @@ public:
   enum RenderMode {SRC,XOR};
   enum HandleMode {HANDLES,NOHANDLES};
 
-  enum AnalysisMethod {STATS,PLOT2D,PLOT3D};
-  enum AnalysisParamType {SUM,AVERAGE};
+  enum AnalysisTask {STATS,PLOT2D,PLOT3D,RADIAL,PANDA};
+  enum AnalysisMethod {SUM,AVERAGE};
 
 protected:
   int id;
@@ -62,7 +62,7 @@ protected:
   int selected;
   int highlited;
 
-  int dashlist[2];
+  float dlist[2];
 
   char* text;
   Tk_Font tkfont_;
@@ -89,9 +89,12 @@ protected:
   static char* analysisPlot2dCB_[];
   int analysisPlot3d_;
   static char* analysisPlot3dCB_[];
-  AnalysisParamType analysisParam_;
-  Coord::CoordSystem analysisSystem_;
-  Coord::SkyFrame analysisSky_;
+  int analysisPanda_;
+  static char* analysisPandaCB_[];
+  int analysisRadial_;
+  static char* analysisRadialCB_[];
+  int analysisStats_;
+  static char* analysisStatsCB_[];
 
  protected:
   virtual void renderX(Drawable, Coord::InternalSystem, RenderMode) =0;
@@ -135,6 +138,9 @@ protected:
   void analysisPlot2dResult(char*, char*, char*, char*, 
 			    double*, double*, double*, double*, int);
   void analysisPlot3dResult(char*, char*, double*, double*, int);
+  void analysisPandaResult(double*, double*, double*, int);
+  void analysisRadialResult(char*, char*, char*, 
+			    double*, double*, double*, int);
 
   void setMatrices(Coord::InternalSystem, Matrix*, Matrix*);
   double calcAngle();
@@ -196,7 +202,7 @@ protected:
 	 const List<Tag>& tag, const List<CallBack>& cb);
   virtual ~Marker();
 
-  virtual void draw(Drawable, Coord::InternalSystem, int, RenderMode, HandleMode);
+  virtual void x11(Drawable, Coord::InternalSystem, int, RenderMode,HandleMode);
   virtual void ps(int,int);
 #ifdef _MACOSX
   virtual void macosx(int);
@@ -227,10 +233,12 @@ protected:
   virtual void rotate(const Vector& v, int h);
   virtual void rotateEnd();
 
-  virtual void analysis(AnalysisMethod, int) {}
-  
   virtual int isIn(const Vector& vv) {return bbox.isIn(vv);}
-  virtual int isIn(const Vector&, Coord::InternalSystem);
+  virtual int isIn(const Vector& vv, Coord::InternalSystem sys);
+  virtual int isIn(const Vector& vv, Coord::InternalSystem sys, int nn)
+  {return isIn(vv,sys);}
+  virtual int isIn(const Vector& vv, Coord::InternalSystem sys, int nn, int aa)
+  {return isIn(vv,sys);}
 
   void setAngle(double);
   double getAngle() {return angle;}
@@ -316,15 +324,15 @@ protected:
   void disableCB() {doCB = 0;}
   void deleteCBs();
 
-  virtual void analysisPlot2d(char*, char*, char*, char*) {}
-  virtual void analysisPlot3d(char*, char*) {}
-
-  AnalysisParamType analysisParam() {return analysisParam_;}
-  void setAnalysisParam(AnalysisParamType mm) {analysisParam_ = mm;}
-  Coord::CoordSystem analysisSystem() {return analysisSystem_;}
-  void setAnalysisSystem(Coord::CoordSystem sys) {analysisSystem_ = sys;}
-  Coord::SkyFrame analysisSky() {return analysisSky_;}
-  void setAnalysisSky(Coord::SkyFrame sky) {analysisSky_ = sky;}
+  virtual void analysis(AnalysisTask, int) {}
+  virtual void analysisPanda(Coord::CoordSystem) {}
+  virtual void analysisRadial(char*, char*, char*, Coord::CoordSystem) {}
+  virtual void analysisStats(Coord::CoordSystem) {}
+  virtual void analysisPlot2d(char*, char*, char*, char*,
+			      Coord::CoordSystem, Coord::SkyFrame, 
+			      Marker::AnalysisMethod) {}
+  virtual void analysisPlot3d(char*, char*, Coord::CoordSystem, 
+			      Marker::AnalysisMethod) {}
 
   // special composite funtionality
   virtual void setComposite(const Matrix&, double);
