@@ -85,8 +85,9 @@ class Point : public Marker {
   void rotate(const Vector& v, int h) {}
   void rotateEnd() {}
 
-  void analysis(AnalysisMethod, int);
-  void analysisPlot3d(char*, char*);
+  void analysis(AnalysisTask, int);
+  void analysisPlot3d(char*, char*, Coord::CoordSystem sys, 
+		      Marker::AnalysisMethod);
 
   void list(ostream&, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, int, int);
   void listXML(ostream&, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat);
