@@ -17,8 +17,8 @@ static void crashHandler(int dummy) {
 #define INTERP interp
 #define SETSIGBUS \
   if (sigsetjmp(crashbuf, 1)) { \
-    Tcl_SetVar2(INTERP, "ds9", "msg", "SIGBUS has been received. Please exit Immdiately.", TCL_GLOBAL_ONLY); \
-    Tcl_SetVar2(INTERP, "ds9", "msg,level", "error", TCL_GLOBAL_ONLY); \
+    Tcl_SetVar2(INTERP, "ds9", "msg", "A fatal SIGBUS error has been received. Please exit Immediately.", TCL_GLOBAL_ONLY); \
+    Tcl_SetVar2(INTERP, "ds9", "msg,level", "fatal", TCL_GLOBAL_ONLY); \
   } \
   else { \
     sigact.sa_handler = crashHandler; \
