@@ -734,7 +734,7 @@ proc AnalysisReaderFinish {ch which i} {
 	image -
 	text {}
 	plot {
-	    AnalysisPlot "at${which}${i}" \
+	    PlotLine "at${which}${i}" \
 		$ianalysis($which,$i,item) \
 		$ianalysis($which,$i,plot,title) \
 		$ianalysis($which,$i,plot,xaxis) \
@@ -743,7 +743,7 @@ proc AnalysisReaderFinish {ch which i} {
 		$ianalysis($which,$i,result)
 	}
 	plotstdin {
-	    AnalysisPlotStdin "at${which}${i}" $ianalysis($which,$i,item) \
+	    AnalysisPlotStdin line "at${which}${i}" $ianalysis($which,$i,item) \
 		$ianalysis($which,$i,result)
 	}
 	default {puts stdout $ianalysis($which,$i,result)}
@@ -752,7 +752,7 @@ proc AnalysisReaderFinish {ch which i} {
     AnalysisTaskEnd $which $i
 }
 
-proc AnalysisPlotStdin {w wtt result} {
+proc AnalysisPlotStdin {type w wtt result} {
     # if no result, just return
     if {$result == {}} {
 	return
@@ -800,7 +800,11 @@ proc AnalysisPlotStdin {w wtt result} {
     set d [lindex $tt [expr $l-1]]
 
     if {$d != {} && $rr != {}} {
-	AnalysisPlot $w $wtt $t $x $y $d $rr
+	switch $type {
+	    line {PlotLine $w $wtt $t $x $y $d $rr}
+	    bar {PlotBar $w $wtt $t $x $y $d $rr}
+	    scatter {PlotScatter $w $wtt $t $x $y $d $rr}
+	}
     } else {
 	Error "[msgcat::mc {Error}] [string range $tt 0 40]"
     }
@@ -837,14 +841,14 @@ proc AnalysisProcessGetURL {which i result} {
     switch -- $ianalysis($which,$i,finish) {
 	text {AnalysisText "at${which}${i}" $ianalysis($which,$i,item) \
 		  $ianalysis($which,$i,result) append}
-	plot {AnalysisPlot "at${which}${i}" \
+	plot {PlotLine "at${which}${i}" \
 		  $ianalysis($which,$i,item) \
 		  $ianalysis($which,$i,plot,title) \
 		  $ianalysis($which,$i,plot,xaxis) \
 		  $ianalysis($which,$i,plot,yaxis) \
 		  $ianalysis($which,$i,plot,dim) \
 		  $ianalysis($which,$i,result)}
-	plotstdin {AnalysisPlotStdin "at${which}${i}" \
+	plotstdin {AnalysisPlotStdin line "at${which}${i}" \
 		       $ianalysis($which,$i,item) \
 		       $ianalysis($which,$i,result)}
 	image {
@@ -1708,11 +1712,6 @@ if {[regexp $exp $cmd]} {
 }
 }
 
-proc AnalysisPlotTool {} {
-    global iap
-    AnalysisPlot $iap(tt) [msgcat::mc {Plot Tool}] {} {} {} 2 {}
-}
-
 proc AnalysisText {tt title txt method} {
     if {$txt != {} && $txt != "\n"} {
 	SimpleTextDialog ${tt}txt $title 80 20 $method bottom $txt
@@ -1861,9 +1860,9 @@ proc ProcessAnalysisPlotCmd {varname iname buf} {
 
     global iap
     switch -- [string tolower [lindex $var $i]] {
-	stdin {AnalysisPlotStdin $iap(tt) {} $buf}
+	stdin {AnalysisPlotStdin line $iap(tt) {} $buf}
 	default {
-	    AnalysisPlot $iap(tt) Plot \
+	    PlotLine $iap(tt) Plot \
 		[lindex $var [expr $i+0]] \
 		[lindex $var [expr $i+1]] \
 		[lindex $var [expr $i+2]] \
