@@ -165,7 +165,7 @@ proc Restore {fn} {
     # kill all plots
     global iap
     foreach varname $iap(windows) {
-	APDestroy $varname
+	PlotDestroy $varname
     }
 
     set dir [file dirname $fn]
@@ -242,7 +242,6 @@ proc BackupFrame {ch which dir} {
     }
 
     MagnifierFrameBackup $ch $which
-    PannerFrameBackup $ch $which
     ColorFrameBackup $ch $which
     ColormapFrameBackup $ch $which
 
@@ -306,8 +305,7 @@ proc BackupFrameLoad {ch which fdir rdir channel} {
 			}
 		    }
 		    set param(file,name) \
-			"$rdir/[lindex [file split $param(file,name)] end]"		
-
+			"$rdir/[lindex [file split $param(file,name)] end]"
 		} else {
 		    if {[file pathtype $param(file,name)] == {relative}} {
 			set param(file,name) [file join [pwd] $param(file,name)]
@@ -315,7 +313,61 @@ proc BackupFrameLoad {ch which fdir rdir channel} {
 		}
 	    }
 	    alloc -
-	    allocgz -
+	    allocgz {
+		# can we find a file?
+		set id [string first "\[" $param(file,name)]
+		if {$id > 0} {
+		    set fn [string range $param(file,name) 0 [expr $id-1]]
+		} else {
+		    set fn $param(file,name)
+		}
+		    
+		if {[file exists $fn]} {
+		    # treat like mmap
+		    if {$pds9(backup)} {
+			set src [lindex [file split $fn] end]
+			if {![file exists [file join $fdir $src]]} {
+			    if {[catch {file copy $fn $fdir}]} {
+				Error [msgcat::mc {An error has occurred during backup}]
+				return
+			    }
+			}
+			set param(file,name) \
+			    "$rdir/[lindex [file split $param(file,name)] end]"
+		    } else {
+			if {[file pathtype $param(file,name)] == {relative}} {
+			    set param(file,name) [file join [pwd] $param(file,name)]
+			}
+		    }
+		} else {
+		    # treat like socket
+		    set param(load,type) mmapincr
+		    set param(file,type) fits
+
+		    set ff [$which get fits file name root base]
+		    set id [string first "\[" $ff]
+		    if {$id > 0} {
+			set fn [string range $ff 0 [expr $id-1]]
+		    } else {
+			set fn $ff
+		    }
+
+		    if {$ff == {}} {
+			set ff ds9.fits
+			set fn ds9.fits
+		    }
+
+		    set ffn [file join $fdir $fn]
+		    if {![file exists $ffn]} {
+			if [$which has fits bin] {
+			    $which save fits table file \"$ffn\"
+			} else {
+			    $which save fits image file \"$ffn\"
+			}
+		    }
+		    set param(file,name) "[file join $rdir $ff]"		
+		}
+	    }
 	    channel -
 	    socket -
 	    socketgz -
