@@ -28,6 +28,14 @@ proc CATDef {} {
     set icat(key) {}
     set icat(key,update) {}
 
+    set icat(match1) {}
+    set icat(match2) {}
+    set icat(return) 1and2
+    set icat(error) 5
+    set icat(eformat) arcsec
+    set icat(function) 1and2
+    set icat(unique) 1
+
     set icat(def) { \
 		       {- {Database} db} \
 		       {{NED} catned ned ned} \
@@ -46,6 +54,8 @@ proc CATDef {} {
 		       {{SAO J2000} catsao cds {I/131A/sao}} \
 		       {{SDSS Release 5} catsdss5 cds {II/276}} \
 		       {{SDSS Release 6} catsdss6 cds {II/282}} \
+		       {{SDSS Release 7} catsdss7 cds {II/294}} \
+		       {{SDSS Release 8} catsdss8 cds {II/306}} \
 		       {{Tycho-2} cattycho cds {I/259/tyc2}} \
 		       {{USNO-A2.0} catua2 cds {I/252/out}} \
 		       {{USNO-B1.0} catub1 cds {I/284/out}} \
@@ -310,6 +320,8 @@ proc CATLoadDone {varname} {
     CATConfigCols $varname
     CATColsMenu $varname
     CATTable $varname
+
+    CATDialogUpdate $varname
 }
 
 # Load via File
@@ -374,7 +386,6 @@ proc CATLoadFn {varname fn reader} {
     }
 
     ARDone $varname
-
     CATLoadDone $varname
 }
 
@@ -416,10 +427,21 @@ proc CATSaveFn {varname fn writer} {
 
 # Other procedures
 
+proc CATStatusRows {varname rowlist} {
+    upvar #0 $varname var
+    global $varname
+
+    # rowlist start at 1
+    if {[llength $rowlist]>0} {
+	ARStatus $varname "[msgcat::mc {Row}] [join $rowlist {,}]"
+    } else {
+	ARStatus $varname {}
+    }
+}
+
 proc CATOff {varname} {
     upvar #0 $varname var
     global $varname
-    global current
 
     global $var(catdb)
     if [info exists $var(catdb)] {
@@ -434,7 +456,9 @@ proc CATOff {varname} {
 
     $var(tbl) selection clear all
 
-    $var(frame) marker catalog $varname delete
+    if {[$var(frame) has fits]} {
+	$var(frame) marker catalog $varname delete
+    }
 
     CATSortMenu $varname
     CATColsMenu $varname
@@ -444,6 +468,19 @@ proc CATOff {varname} {
     set var(coly) {}
 
     set var(blink) 0
+
+    # plot window?
+    if {$var(plot)} {
+	PlotDestroy $var(plot,var)
+	set var(plot) 0
+	set var(plot,var) {}
+	set var(plot,x) {}
+	set var(plot,xerr) {}
+	set var(plot,y) {}
+	set var(plot,yerr) {}
+    }
+
+    CATDialogUpdate $varname
 }
 
 # used by backup
@@ -473,7 +510,9 @@ proc CATTable {varname} {
     $var(tbl) selection clear all
 
     # clear regions
-    $var(frame) marker catalog $varname delete
+    if {[$var(frame) has fits]} {
+	$var(frame) marker catalog $varname delete
+    }
 
     if {$var(filter) == {} && $var(sort) == {}} {
 	set var(tbldb) $var(catdb)
@@ -516,7 +555,12 @@ proc CATTable {varname} {
 	$var(tbl) configure -rows $icat(minrows)
     }
 
-    CATPlot $varname
+    CATGenerate $varname
+
+    # regenerate the plot if needed
+    if {$var(plot)} {
+	CATPlotGenerate $varname
+    }
 
     set nr [starbase_nrows $var(tbldb)]
     if {$nr >= $var(max) && !$var(allrows)} {
@@ -524,14 +568,14 @@ proc CATTable {varname} {
     }
 }
 
-proc CATPlot {varname} {
+proc CATGenerate {varname} {
     upvar #0 $varname var
     global $varname
     global $var(tbldb)
 
     global debug
     if {$debug(tcl,cat)} {
-	puts stderr "CATPlot $varname"
+	puts stderr "CATGenerate $varname"
     }
 
     # do we have a db?
@@ -542,29 +586,33 @@ proc CATPlot {varname} {
     ARStatus $varname [msgcat::mc {Plotting Regions}]
 
     # delete any previous 
-    $var(frame) marker catalog $varname delete
+    if {[$var(frame) has fits]} {
+	$var(frame) marker catalog $varname delete
+    }
 
     if {$var(show)} {
 	global reg
 	set reg {}
 	CATReg $varname {} 1 reg
-	if [catch {$var(frame) marker catalog command ds9 var reg}] {
-	    ARError $varname "[msgcat::mc {Internal Parse Error}]"
-	    return
+	if {[$var(frame) has fits]} {
+	    if {[catch {$var(frame) marker catalog command ds9 var reg}]} {
+		ARError $varname "[msgcat::mc {Internal Parse Error}]"
+		return
+	    }
 	}
     }
 
     ARStatus $varname {Done}
 }
 
-proc CATPlotRegions {varname} {
+proc CATGenerateRegions {varname} {
     upvar #0 $varname var
     global $varname
     global $var(tbldb)
 
     global debug
     if {$debug(tcl,cat)} {
-	puts stderr "CATPlotRegions $varname"
+	puts stderr "CATGenerateRegions $varname"
     }
 
     # do we have a db?
@@ -577,23 +625,29 @@ proc CATPlotRegions {varname} {
     global reg
     set reg {}
     CATReg $varname {} 0 reg
-    if [catch {$var(frame) marker command ds9 var reg}] {
-	ARError $varname "[msgcat::mc {Internal Parse Error}]"
-	return
+    if {[$var(frame) has fits]} {
+	if {[catch {$var(frame) marker command ds9 var reg}]} {
+	    ARError $varname "[msgcat::mc {Internal Parse Error}]"
+	    return
+	}
     }
 
     ARStatus $varname {Done}
 }
 
-proc CATPlotUpdate {varname row} {
+proc CATGenerateUpdate {varname row} {
     upvar #0 $varname var
     global $varname
 
     global debug
     if {$debug(tcl,cat)} {
-	puts stderr "CATPlotUpdate $varname $row"
+	puts stderr "CATGenerateUpdate $varname $row"
     }
 
+    if {![$var(frame) has fits]} {
+	return
+    }
+    
     set id [$var(frame) get marker catalog "\{${varname}.${row}\}" id]
     set sel [$var(frame) get marker catalog $id select]
     set hh [$var(frame) get marker catalog $id highlite]
@@ -790,7 +844,7 @@ proc CATColXCmd {varname val} {
     global $varname
 
     set ${varname}(colx) $val
-    CATPlot $varname
+    CATGenerate $varname
 }
 
 proc CATColYCmd {varname val} {
@@ -798,7 +852,7 @@ proc CATColYCmd {varname val} {
     global $varname
 
     set ${varname}(coly) $val
-    CATPlot $varname
+    CATGenerate $varname
 }
 
 proc CATColsCmd {varname} {
@@ -806,7 +860,7 @@ proc CATColsCmd {varname} {
     global $varname
 
     CATColsUpdate $varname
-    CATPlot $varname
+    CATGenerate $varname
 }
 
 proc CATConfigCols {varname} {
@@ -988,11 +1042,11 @@ proc CATConfigColsSearch {varname cols} {
 
 # Other interface
 
-proc CATOther {} {
-    CATDialog catoth {} {} {} none
+proc CATTool {} {
+    CATDialog cattool {} {} {} none
 }
 
-proc CATClearCurrentFrame {} {
+proc CATClearFrame {} {
     global current
 
     if {$current(frame) != {}} {
@@ -1011,7 +1065,12 @@ proc CATUpdateWCS {} {
 	    upvar #0 $varname var
 	    global $varname
 
-	    CATPlot $varname
+	    CATGenerate $varname
+
+	    # regenerate the plot if needed
+	    if {$var(plot)} {
+		CATPlotGenerate $varname
+	    }
 	}
     }
 }
@@ -1062,62 +1121,22 @@ proc ProcessCatalogCmd {varname iname} {
     upvar $iname i
 
     global icat
-    global pcat
 
     # we need to be realized
     ProcessRealizeDS9
 
-    set cvarname {}
-
-    # determine catalog name
     set item [string tolower [lindex $var $i]]
     switch -- $item {
-	cds -
-	cxc -
-	ned -
-	skybot -
-	sdss -
-	simbad {
-	    # see if its from our list of cats
-	    incr i
-	    set which [string tolower [lindex $var $i]]
-	    foreach mm $icat(def) {
-		set ll [lindex $mm 0]
-		set ww [lindex $mm 1]
-		set ss [lindex $mm 2]
-		set cc [lindex $mm 3]
-		
-		if {$ll != {-} && "cat${which}" == $ww} {
-		    CATDialog $ww $ss $cc $ll sync
-		    return
-		}
-	    }
-
-	    # not a default, assume other name
-	    switch -- $item {
-		cds {CATDialog catoth $item $which $which sync}
-		cxc {CATDialog catcsc cxc {Current Release} {Chandra Source} sync}
-		ned {CATDialog catned ned ned {NED} sync}
-		skybot {CATDialog catskybot skybot skybot {SkyBot} sync}
-		simbad {CATDialog catsimbad simbad simbad {SIMBAD} sync}
-		sdss {CATDialog catsdss6 sdss 6 {SDSS Release 6} sync}
-	    }
-
-	    # clean up from above
-	    switch -- $item {
-		cds {}
-		cxc -
-		ned -
-		skybot -
-		simbad -
-		sdss {incr i -1}
-	    }
-
+	{} {
+	    # blank
+	    CATTool
 	    return
 	}
 
 	file -
+	import -
 	load {
+	    # load
 	    incr i
 	    set reader CATVOTRead
 	    switch -- [lindex $var $i] {
@@ -1131,87 +1150,155 @@ proc ProcessCatalogCmd {varname iname} {
 
 	    set fn [lindex $var $i]
 	    if {$fn != {}} {
-		CATDialog catoth {} {} {} none
+		CATDialog cattool {} {} {} none
 		CATLoadFn [lindex $icat(cats) end] $fn $reader
 		FileLast catfbox $fn
 	    }
 	    return
 	}
 
-	samp -
-	name -
-	coordinate -
-	system -
-	sky -
-	skyformat -
-	size -
-	update -
-	crosshair -
-	save -
-	header -
-	filter -
-	clear -
-	retrieve -
-	cancel -
-	print -
-	close -
-	server -
-	symbol -
-	sort -
-	maxrows -
 	allcols -
 	allrows -
-	x -
-	ra -
-	y -
+	cancel -
+	clear -
+	close -
+	coordinate -
+	crosshair -
 	dec -
-	psystem -
-	psky -
-	show -
-	hide -
 	edit -
-	panto {set cvarname [lindex $icat(cats) end]}
+	export -
+	filter -
+	header -
+	hide -
+	location -
+	match -
+	maxrows -
+	name -
+	panto -
+	plot -
+	print -
+	psky -
+	psystem -
+	ra -
+	retrieve -
+	samp -
+	save -
+	server -
+	show -
+	size -
+	sky -
+	skyformat -
+	sort -
+	symbol -
+	system -
+	update -
+	x -
+	y {ProcessCatalog $varname $iname [lindex $icat(cats) end]}
 
 	default {
-	    # blank
-	    if {$item == {}} {
-		CATOther
-		return
-	    }
-	    # another command
-	    if {[string range $item 0 0] == "-"} {
-		CATOther
-		incr i -1
-		return
+	    # existing cat or load new one?
+	    set ref $item
+
+	    # backward compatibility
+	    if {[string range $ref 0 2] == {cat}} {
+		set ref [string range $ref 3 end]
 	    }
 
-	    # is it an existing cat?
-	    if {[lsearch $icat(cats) $item] == -1} {
-		set which $item
-		foreach mm $icat(def) {
-		    set ll [lindex $mm 0]
-		    set ww [lindex $mm 1]
-		    set ss [lindex $mm 2]
-		    set cc [lindex $mm 3]
-		    
-		    if {$ll != {-} && "cat${which}" == $ww} {
-			CATDialog $ww $ss $cc $ll sync
+	    incr i
+	    set item [string tolower [lindex $var $i]]
+	    switch -- $item {
+		file -
+		import -
+		load {
+		    # processed above
+		    incr i -1
+		    return
+		}
+
+		allcols -
+		allrows -
+		cancel -
+		clear -
+		close -
+		coordinate -
+		crosshair -
+		dec -
+		edit -
+		export -
+		filter -
+		header -
+		hide -
+		location -
+		match -
+		maxrows -
+		name -
+		panto -
+		plot -
+		print -
+		psky -
+		psystem -
+		ra -
+		retrieve -
+		samp -
+		save -
+		server -
+		show -
+		size -
+		sky -
+		skyformat -
+		sort -
+		symbol -
+		system -
+		update -
+		x -
+		y {ProcessCatalog $varname $iname cat${ref}}
+
+		default {
+		    # ok, new catalog
+		    incr i -1
+		    set item [string tolower [lindex $var $i]]
+
+		    # another command
+		    if {[string range $item 0 0] == "-"} {
+			CATTool
+			incr i -1
 			return
 		    }
-		}
 
-		# not a default, assume other name
-		switch -- $item {
-		    cds {CATDialog catoth $item $which $which sync}
-		}
+		    # backward compatibility
+		    switch $item {
+			cds {incr i; set item [string tolower [lindex $var $i]]}
+			cxc {set item csc}
+		    }
 
-		return
-	    } else {
-		set cvarname $item
-		incr i
+		    # see if its from our list of cats
+		    foreach mm $icat(def) {
+			set ll [lindex $mm 0]
+			set ww [lindex $mm 1]
+			set ss [lindex $mm 2]
+			set cc [lindex $mm 3]
+
+			if {$ll != {-} && "cat${item}" == $ww} {
+			    CATDialog $ww $ss $cc $ll sync
+			    return
+			}
+		    }
+
+		    # not a default, assume other name
+		    CATDialog catcds cds $item $item sync
+		}
 	    }
 	}
     }
+}
+
+proc ProcessCatalog {varname iname cvarname} {
+    upvar 2 $varname var
+    upvar 2 $iname i
+
+    global icat
+    global pcat
+    global current
 
     # we should have a catalog now
     global $cvarname
@@ -1229,10 +1316,11 @@ proc ProcessCatalogCmd {varname iname} {
     # now, process it
     set item [string tolower [lindex $var $i]]
     switch -- $item {
-	name {
-	    incr i
-	    set cvar(name) [lindex $var $i]
-	}
+	allrows {set cvar(allrows) 1}
+	allcols {set cvar(allcols) 1}
+	cancel {ARCancel $cvarname}
+	clear {CATOff $cvarname}
+	close {CATDestroy $cvarname}
 	coordinate {
 	    incr i
 	    set cvar(x) [lindex $var $i]
@@ -1241,32 +1329,13 @@ proc ProcessCatalogCmd {varname iname} {
 	    incr i
 	    set cvar(sky) [lindex $var $i]
 	}
-	update {CATUpdate $cvarname}
 	crosshair {CATCrosshair $cvarname}
-	system {
+	edit {
 	    incr i
-	    set cvar(system) [lindex $var $i]
-	    CoordMenuButtonCmd $cvarname system sky \
-		[list CATWCSMenuUpdate $cvarname]
-	}
-	sky {
-	    incr i
-	    set cvar(sky) [lindex $var $i]
-	    CoordMenuButtonCmd $cvarname system sky \
-		[list CATWCSMenuUpdate $cvarname]
-	}
-	skyformat {
-	    incr i
-	    set cvar(skyformat) [lindex $var $i]
-	}
-	size {
-	    incr i
-	    set cvar(width) [lindex $var $i]
-	    incr i
-	    set cvar(height) [lindex $var $i]
-	    incr i
-	    set cvar(rformat) [lindex $var $i]
+	    set cvar(edit) [FromYesNo [lindex $var $i]]
+	    CATEdit $cvarname
 	}
+	export -
 	save {
 	    incr i
 	    set writer CATVOTWrite
@@ -1283,7 +1352,6 @@ proc ProcessCatalogCmd {varname iname} {
 	    CATSaveFn $cvarname $fn $writer
 	    FileLast catfbox $fn
 	}
-	header {}
 	filter {
 	    incr i
 	    set item [lindex $var $i]
@@ -1306,208 +1374,73 @@ proc ProcessCatalogCmd {varname iname} {
 	    }
 	    CATTable $cvarname
 	}
-	clear {CATOff $cvarname}
-	retrieve -
-	retreive {CATApply $cvarname 1}
-	cancel {ARCancel $cvarname}
-	print {CATPrint $cvarname}
-	close {CATDestroy $cvarname}
-	server {
-	    incr i
-	    set $cvar(server) [lindex $var $i]
+	header {CATHeader $cvarname}
+	hide {
+	    set cvar(show) 0
+	    CATGenerate $cvarname
 	}
-	symbol {
-	    global $cvar(symdb)
-	    set row 1
+	location {
 	    incr i
-	    if {[string is integer [lindex $var $i]]} {
-		set row [lindex $var $i]
-		incr i
-	    }
-
-	    switch -- [lindex $var $i] {
-		condition {
-		    incr i
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) condition] \
-			[lindex $var $i]
-		    CATPlot $cvarname
-		}
-		shape {
-		    incr i
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) shape] [lindex $var $i]
-		    CATPlot $cvarname
-		}
-		color {
-		    incr i
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) color] [lindex $var $i]
-		    CATPlot $cvarname
-		}
-		font {
-		    incr i
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) font] [lindex $var $i]
-		    CATPlot $cvarname
-		}
-		fontsize {
-		    incr i
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) fontsize] [lindex $var $i]
-		    CATPlot $cvarname
-		}
-		fontweight {
-		    incr i
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) fontweight] \
-			[lindex $var $i]
-		    CATPlot $cvarname
-		}
-		fontslant {
-		    incr i
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) fontslant] \
-			[lindex $var $i]
-		    CATPlot $cvarname
-		}
-		text {
-		    incr i
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) text] [lindex $var $i]
-		    CATPlot $cvarname
-		}
-		size {
-		    incr i
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) size] [lindex $var $i]
-		    CATPlot $cvarname
-		}
-		size2 {
-		    incr i
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) size2] [lindex $var $i]
-		    CATPlot $cvarname
-		}
-		units {
-		    incr i
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) units] [lindex $var $i]
-		    CATPlot $cvarname
-		}
-		angle {
-		    incr i
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) angle] [lindex $var $i]
-		    CATPlot $cvarname
-		}
-
-		add {
-		    set row [expr [starbase_nrows $cvar(symdb)]+1]
-		    starbase_rowins $cvar(symdb) $row
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) shape] $pcat(sym,shape)
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) color] $pcat(sym,color)
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) font] $pcat(sym,font)
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) fontsize] \
-			$pcat(sym,font,size)
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) fontweight] \
-			$pcat(sym,font,weight)
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) fontslant] \
-			$pcat(sym,font,slant)
-		    starbase_set $cvar(symdb) $row \
-			[starbase_colnum $cvar(symdb) units] $pcat(sym,units)
-		    CATPlot $cvarname
-		}
-		remove {
-		    starbase_rowdel $cvar(symdb) $row
-		    CATPlot $cvarname
-		}
-		save {
-		    incr i
-		    starbase_write $cvar(symdb) [lindex $var $i]
-		}
-		load {
-		    incr i
-		    set fn [lindex $var $i]
-		    if {[file exists $fn]} {
-			starbase_read $cvar(symdb) $fn
-			CATPlot $cvarname
-		    } else {
-			Error "[msgcat::mc {Unable to open file}] $fn"
-			return
-		    }
-		}
-	    }
+	    set cvar(loc) [lindex $var $i]
+	    CATGenerate $cvarname
 	}
-	sort {
+	match {
 	    incr i
-	    set cvar(sort) [lindex $var $i]
-	    incr i
-	    switch -- [lindex $var $i] {
-		incr {
-		    set cvar(sort,dir) "-increasing"
+	    set item [lindex $var $i]
+	    switch -- $item {
+		error {
+		    incr i
+		    set icat(error) [lindex $var $i]
+		    incr i
+		    set icat(eformat) [lindex $var $i]
 		}
-		decr {
-		    set cvar(sort,dir) "-decreasing"
+		function {incr i; set icat(function) [lindex $var $i]}
+		unique {incr i; set icat(unique) [FromYesNo [lindex $var $i]]}
+		return {incr i; set icat(return) [lindex $var $i]}
+		default {
+		    set icat(match1) "cat[lindex $var $i]"
+		    incr i
+		    set icat(match2) "cat[lindex $var $i]"
+		    CATMatch $current(frame) $icat(match1) $icat(match2)
 		}
 	    }
-	    CATTable $cvarname
 	}
 	maxrows {
 	    incr i
 	    set cvar(max) [lindex $var $i]
 	}
-	allrows {
-	    set cvar(allrows) 1
-	}
-	allcols {
-	    set cvar(allcols) 1
-	}
-	show {
-	    set cvar(show) 1
-	    CATPlot $cvarname
-	}
-	hide {
-	    set cvar(show) 0
-	    CATPlot $cvarname
+	name {
+	    incr i
+	    set cvar(name) [lindex $var $i]
 	}
 	panto {
 	    incr i
 	    set cvar(panto) [FromYesNo [lindex $var $i]]
 	}
-	edit {
+	plot {
 	    incr i
-	    set cvar(edit) [FromYesNo [lindex $var $i]]
-	    CATEdit $cvarname
+	    set cvar(plot,x) [lindex $var $i]
+	    incr i
+	    set cvar(plot,y) [lindex $var $i]
+	    incr i
+	    set cvar(plot,xerr) [lindex $var $i]
+	    incr i
+	    set cvar(plot,yerr) [lindex $var $i]
+	    CATPlotGenerate $cvarname
 	}
-	x -
-	ra {
+	print {CATPrint $cvarname}
+	psky {
 	    incr i
-	    set cvar(colx) [lindex $var $i]
-	    CATPlot $cvarname
-	}
-	y -
-	dec {
-	    incr i
-	    set cvar(coly) [lindex $var $i]
-	    CATPlot $cvarname
+	    set cvar(psky) [lindex $var $i]
+	    CATGenerate $cvarname
 	}
 	psystem {
 	    incr i
 	    set cvar(psystem) [lindex $var $i]
-	    CATPlot $cvarname
-	}
-	psky {
-	    incr i
-	    set cvar(psky) [lindex $var $i]
-	    CATPlot $cvarname
+	    CATGenerate $cvarname
 	}
+	retrieve -
+	retreive {CATApply $cvarname 1}
 	samp {
 	    global ds9
 	    global samp
@@ -1537,6 +1470,193 @@ proc ProcessCatalogCmd {varname iname} {
 		}
 	    }
 	}
+	server {
+	    incr i
+	    set $cvar(server) [lindex $var $i]
+	}
+	size {
+	    incr i
+	    set cvar(width) [lindex $var $i]
+	    incr i
+	    set cvar(height) [lindex $var $i]
+	    incr i
+	    set cvar(rformat) [lindex $var $i]
+	}
+	show {
+	    set cvar(show) 1
+	    CATGenerate $cvarname
+	}
+	sky {
+	    incr i
+	    set cvar(sky) [lindex $var $i]
+	    CoordMenuButtonCmd $cvarname system sky \
+		[list CATWCSMenuUpdate $cvarname]
+	}
+	skyformat {
+	    incr i
+	    set cvar(skyformat) [lindex $var $i]
+	}
+	sort {
+	    incr i
+	    set cvar(sort) [lindex $var $i]
+	    incr i
+	    switch -- [lindex $var $i] {
+		incr {
+		    set cvar(sort,dir) "-increasing"
+		}
+		decr {
+		    set cvar(sort,dir) "-decreasing"
+		}
+	    }
+	    CATTable $cvarname
+	}
+	symbol {
+	    global $cvar(symdb)
+	    set row 1
+	    incr i
+	    if {[string is integer [lindex $var $i]]} {
+		set row [lindex $var $i]
+		incr i
+	    }
+
+	    switch -- [lindex $var $i] {
+		add {
+		    set row [expr [starbase_nrows $cvar(symdb)]+1]
+		    starbase_rowins $cvar(symdb) $row
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) shape] $pcat(sym,shape)
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) color] $pcat(sym,color)
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) font] $pcat(sym,font)
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) fontsize] \
+			$pcat(sym,font,size)
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) fontweight] \
+			$pcat(sym,font,weight)
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) fontslant] \
+			$pcat(sym,font,slant)
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) units] $pcat(sym,units)
+		    CATGenerate $cvarname
+		}
+		angle {
+		    incr i
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) angle] [lindex $var $i]
+		    CATGenerate $cvarname
+		}
+		color {
+		    incr i
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) color] [lindex $var $i]
+		    CATGenerate $cvarname
+		}
+		condition {
+		    incr i
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) condition] \
+			[lindex $var $i]
+		    CATGenerate $cvarname
+		}
+		font {
+		    incr i
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) font] [lindex $var $i]
+		    CATGenerate $cvarname
+		}
+		fontsize {
+		    incr i
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) fontsize] [lindex $var $i]
+		    CATGenerate $cvarname
+		}
+		fontweight {
+		    incr i
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) fontweight] \
+			[lindex $var $i]
+		    CATGenerate $cvarname
+		}
+		fontslant {
+		    incr i
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) fontslant] \
+			[lindex $var $i]
+		    CATGenerate $cvarname
+		}
+		load {
+		    incr i
+		    set fn [lindex $var $i]
+		    if {[file exists $fn]} {
+			starbase_read $cvar(symdb) $fn
+			CATGenerate $cvarname
+		    } else {
+			Error "[msgcat::mc {Unable to open file}] $fn"
+			return
+		    }
+		}
+		remove {
+		    starbase_rowdel $cvar(symdb) $row
+		    CATGenerate $cvarname
+		}
+		save {
+		    incr i
+		    starbase_write $cvar(symdb) [lindex $var $i]
+		}
+		size {
+		    incr i
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) size] [lindex $var $i]
+		    CATGenerate $cvarname
+		}
+		size2 {
+		    incr i
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) size2] [lindex $var $i]
+		    CATGenerate $cvarname
+		}
+		shape {
+		    incr i
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) shape] [lindex $var $i]
+		    CATGenerate $cvarname
+		}
+		text {
+		    incr i
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) text] [lindex $var $i]
+		    CATGenerate $cvarname
+		}
+		units {
+		    incr i
+		    starbase_set $cvar(symdb) $row \
+			[starbase_colnum $cvar(symdb) units] [lindex $var $i]
+		    CATGenerate $cvarname
+		}
+	    }
+	}
+	system {
+	    incr i
+	    set cvar(system) [lindex $var $i]
+	    CoordMenuButtonCmd $cvarname system sky \
+		[list CATWCSMenuUpdate $cvarname]
+	}
+	update {CATUpdate $cvarname}
+	x -
+	ra {
+	    incr i
+	    set cvar(colx) [lindex $var $i]
+	    CATGenerate $cvarname
+	}
+	y -
+	dec {
+	    incr i
+	    set cvar(coly) [lindex $var $i]
+	    CATGenerate $cvarname
+	}
     }
 }
 
