@@ -79,6 +79,13 @@ proc CATDialog {varname format catalog title action} {
     set var(blink,count) 0
     set var(blink,marker) {}
 
+    set var(plot) 0
+    set var(plot,var) {}
+    set var(plot,x) {}
+    set var(plot,xerr) {}
+    set var(plot,y) {}
+    set var(plot,yerr) {}
+
     CATSet $varname $format $catalog $title
     CATSymDBInit $varname
 
@@ -102,35 +109,46 @@ proc CATDialog {varname format catalog title action} {
 
     # file
     menu $mb.file
-    $mb.file add cascade -label [msgcat::mc {Load}] -menu $mb.file.load
-    $mb.file add cascade -label [msgcat::mc {Save}] -menu $mb.file.save
+    $mb.file add command -label "[msgcat::mc {Load}]..." \
+	-command [list CATLoadVOTFile $varname]
+    $mb.file add command -label "[msgcat::mc {Save}]..." \
+	-command [list CATSaveVOTFile $varname]
     $mb.file add separator
-    $mb.file add command -label "[msgcat::mc {Display Catalog Header}]..." \
-	-command "CATHeader $varname"
-    $mb.file add separator
-    $mb.file add command -label [msgcat::mc {Filter}] \
-	-command "CATTable $varname"
-    $mb.file add command -label [msgcat::mc {Clear}] \
-	-command "CATOff $varname"
+    $mb.file add cascade -label [msgcat::mc {Import}] -menu $mb.file.import
+    $mb.file add cascade -label [msgcat::mc {Export}] -menu $mb.file.export
     $mb.file add separator
     $mb.file add command -label [msgcat::mc {Retrieve}] \
-	-command "CATApply $varname 0"
+	-command [list CATApply $varname 0]
     $mb.file add command -label [msgcat::mc {Cancel}] \
-	-command "ARCancel $varname"
+	-command [list ARCancel $varname]
+    $mb.file add separator
+    $mb.file add command -label [msgcat::mc {Filter}] \
+	-command [list CATTable $varname]
+    $mb.file add command -label [msgcat::mc {Clear}] \
+	-command [list CATOff $varname]
+    $mb.file add separator
+    $mb.file add checkbutton -label [msgcat::mc {Show}] \
+	-variable ${varname}(show) -command [list CATGenerate $varname]
+    $mb.file add checkbutton -label [msgcat::mc {Edit}] \
+	-variable ${varname}(edit) -command [list CATEdit $varname]
     $mb.file add separator
     $mb.file add cascade -label [msgcat::mc {SAMP}] -menu $mb.file.samp
+    $mb.file add command -label [msgcat::mc {Plot}] \
+	-command [list CATPlot $varname]
     $mb.file add separator
+    $mb.file add command -label "[msgcat::mc {Display Header}]..." \
+	-command [list CATHeader $varname]
     $mb.file add command -label [msgcat::mc {Acknowledgment}] \
-	-command "CATAck $varname"
+	-command [list CATAck $varname]
     $mb.file add separator
     $mb.file add command -label [msgcat::mc {Update from Current Frame}] \
-	-command "CATUpdate $varname"
+	-command [list CATUpdate $varname]
     $mb.file add command \
 	-label [msgcat::mc {Update from Current Crosshair}] \
-	-command "CATCrosshair $varname"
+	-command [list CATCrosshair $varname]
     $mb.file add separator
 	$mb.file add command -label [msgcat::mc {Copy to Regions}] \
-	-command "CATPlotRegions $varname"
+	-command [list CATGenerateRegions $varname]
     $mb.file add separator
     switch $ds9(wm) {
 	x11 {}
@@ -141,28 +159,24 @@ proc CATDialog {varname format catalog title action} {
 	}
     }
     $mb.file add command -label "[msgcat::mc {Print}]..." \
-	-command "CATPrint $varname"
+	-command [list CATPrint $varname]
     $mb.file add separator
     $mb.file add command -label [msgcat::mc {Close}] \
-	-command "CATDestroy $varname"
+	-command [list CATDestroy $varname]
 
-    # Load
-    menu $mb.file.load
-    $mb.file.load add command -label "[msgcat::mc {VOTable}]..." \
-	-command "CATLoadVOTFile $varname"
-    $mb.file.load add command -label "[msgcat::mc {Starbase}]..." \
-	-command "CATLoadSBFile $varname"
-    $mb.file.load add command -label "[msgcat::mc {Tab-Separated-Value}]..." \
-	-command "CATLoadTSVFile $varname"
+    # Import
+    menu $mb.file.import
+    $mb.file.import add command -label "[msgcat::mc {Starbase}]..." \
+	-command [list CATLoadSBFile $varname]
+    $mb.file.import add command -label "[msgcat::mc {Tab-Separated-Value}]..." \
+	-command [list CATLoadTSVFile $varname]
 
-    # Save
-    menu $mb.file.save
-    $mb.file.save add command -label "[msgcat::mc {VOTable}]..." \
-	-command "CATSaveVOTFile $varname"
-    $mb.file.save add command -label "[msgcat::mc {Starbase}]..." \
-	-command "CATSaveSBFile $varname"
-    $mb.file.save add command -label "[msgcat::mc {Tab-Separated-Value}]..." \
-	-command "CATSaveTSVFile $varname"
+    # Export
+    menu $mb.file.export
+    $mb.file.export add command -label "[msgcat::mc {Starbase}]..." \
+	-command [list CATSaveSBFile $varname]
+    $mb.file.export add command -label "[msgcat::mc {Tab-Separated-Value}]..." \
+	-command [list CATSaveTSVFile $varname]
 
     # SAMP
     menu $mb.file.samp
@@ -176,14 +190,14 @@ proc CATDialog {varname format catalog title action} {
 
     menu $mb.file.samp.send
     $mb.file.samp.send add command -label [msgcat::mc {Broadcast}] \
-	-command "SAMPSendTableLoadVotable {} $varname"
+	-command [list SAMPSendTableLoadVotable {} $varname]
     $mb.file.samp.send add separator
 
     # edit
     EditMenu $mb $varname
     $mb.edit add separator
     $mb.edit add command -label [msgcat::mc {Clear}] \
-	-command "ARClear $varname"
+	-command [list ARClear $varname]
 
     # symbol
     global $var(symdb)
@@ -201,57 +215,53 @@ proc CATDialog {varname format catalog title action} {
     $mb.symbol add cascade -label [msgcat::mc {Font}] -menu $mb.symbol.font
     $mb.symbol add separator
     $mb.symbol add command -label "[msgcat::mc {Advanced}]..." \
-	-command "CATSymDialog $varname"
+	-command [list CATSymDialog $varname]
 
     menu $mb.symbol.shape
     $mb.symbol.shape add radiobutton -label [msgcat::mc {Circle}] \
 	-variable ${flt}(1,$sn) -value circle \
-	-command "CATPlot $varname"
+	-command [list CATGenerate $varname]
     $mb.symbol.shape add radiobutton -label [msgcat::mc {Ellipse}] \
 	-variable ${flt}(1,$sn) -value ellipse \
-	-command "CATPlot $varname"
+	-command [list CATGenerate $varname]
     $mb.symbol.shape add radiobutton -label [msgcat::mc {Box}] \
 	-variable ${flt}(1,$sn) -value box \
-	-command "CATPlot $varname"
+	-command [list CATGenerate $varname]
     $mb.symbol.shape add radiobutton -label [msgcat::mc {Text}] \
 	-variable ${flt}(1,$sn) -value text \
-	-command "CATPlot $varname"
+	-command [list CATGenerate $varname]
     $mb.symbol.shape add cascade -label [msgcat::mc {Point}] \
 	-menu $mb.symbol.shape.point
 
     menu $mb.symbol.shape.point
     $mb.symbol.shape.point add radiobutton -label [msgcat::mc {Circle}] \
 	-variable ${flt}(1,$sn) -value {circle point} \
-	-command "CATPlot $varname"
+	-command [list CATGenerate $varname]
     $mb.symbol.shape.point add radiobutton -label [msgcat::mc {Box}] \
 	-variable ${flt}(1,$sn) -value {box point} \
-	-command "CATPlot $varname"
+	-command [list CATGenerate $varname]
     $mb.symbol.shape.point add radiobutton -label [msgcat::mc {Diamond}] \
 	-variable ${flt}(1,$sn) -value {diamond point} \
-	-command "CATPlot $varname"
+	-command [list CATGenerate $varname]
     $mb.symbol.shape.point add radiobutton -label [msgcat::mc {Cross}] \
 	-variable ${flt}(1,$sn) -value {cross point} \
-	-command "CATPlot $varname"
+	-command [list CATGenerate $varname]
     $mb.symbol.shape.point add radiobutton -label [msgcat::mc {X}] \
 	-variable ${flt}(1,$sn) -value {x point} \
-	-command "CATPlot $varname"
+	-command [list CATGenerate $varname]
     $mb.symbol.shape.point add radiobutton -label [msgcat::mc {Arrow}] \
 	-variable ${flt}(1,$sn) -value {arrow point} \
-	-command "CATPlot $varname"
+	-command [list CATGenerate $varname]
     $mb.symbol.shape.point add radiobutton -label [msgcat::mc {BoxCircle}]\
 	-variable ${flt}(1,$sn) -value {boxcircle point} \
-	-command "CATPlot $varname"
+	-command [list CATGenerate $varname]
 
-    ColorMenu $mb.symbol.color $flt 1,$cn [list CATPlot $varname]
+    ColorMenu $mb.symbol.color $flt 1,$cn [list CATGenerate $varname]
 
     FontMenu $mb.symbol.font $flt 1,$fn 1,$fs 1,$fw 1,$fl \
-	[list CATPlot $varname]
+	[list CATGenerate $varname]
 
     menu $mb.prefs
-    $mb.prefs add checkbutton -label [msgcat::mc {Show Regions}] \
-	-variable ${varname}(show) -command "CATPlot $varname"
-    $mb.prefs add checkbutton -label [msgcat::mc {Edit}] \
-	-variable ${varname}(edit) -command "CATEdit $varname"
     $mb.prefs add checkbutton -label [msgcat::mc {Pan To}] \
 	-variable ${varname}(panto)
     $mb.prefs add separator
@@ -271,11 +281,16 @@ proc CATDialog {varname format catalog title action} {
     ttk::label $f.cat -textvariable ${varname}(catalog) \
 	-relief groove -width 60 -anchor w
 
+    ttk::label $f.tref -text [msgcat::mc {Reference}]
+    ttk::label $f.ref -text [string range $varname 3 end] \
+	-relief groove -width 13 -anchor w
+
     ttk::label $f.loctitle -text [msgcat::mc {IAU Location Code}]
     ttk::entry $f.loc -textvariable ${varname}(loc) -width 7
 
     grid $f.ttitle $f.title -padx 2 -pady 2 -sticky w
     grid $f.tcat $f.cat -padx 2 -pady 2 -sticky w
+    grid $f.tref $f.ref -padx 2 -pady 2 -sticky w
     grid $f.loctitle $f.loc -padx 2 -pady 2 -sticky w
 
     # Object
@@ -314,7 +329,7 @@ proc CATDialog {varname format catalog title action} {
     ttk::label $f.mfilter -text [msgcat::mc {Filter}]
     ttk::entry $f.filter -textvariable ${varname}(filter) -width 50
     ttk::button $f.bfilter -text [msgcat::mc {Edit}] \
-	-command "CATEditDialog $varname filter $var(catdb)"
+	-command [list CATEditDialog $varname filter $var(catdb)]
 
     ttk::label $f.msort -text [msgcat::mc {Sort}]
     set var(sortmenu) [ttk::menubutton $f.sort \
@@ -322,10 +337,10 @@ proc CATDialog {varname format catalog title action} {
 			   -menu $f.sort.menu -width 14]
     ttk::radiobutton $f.isort -text [msgcat::mc {Increase}] \
 	-variable ${varname}(sort,dir) -value "-increasing" \
-	-command "CATTable $varname"
+	-command [list CATTable $varname]
     ttk::radiobutton $f.dsort -text [msgcat::mc {Decrease}] \
 	-variable ${varname}(sort,dir) -value "-decreasing" \
-	-command "CATTable $varname"
+	-command [list CATTable $varname]
 
     ttk::label $f.mtitle -text [msgcat::mc {Max Rows}]
     ttk::entry $f.max -textvariable ${varname}(max) -width 14
@@ -398,24 +413,29 @@ proc CATDialog {varname format catalog title action} {
     # Buttons
     set f [ttk::frame $w.buttons]
 
-    ttk::button $f.filter -text [msgcat::mc {Filter}] \
-	-command "CATTable $varname"
+    ButtonButton $f.load [msgcat::mc {Load}] [list CATLoadVOTFile $varname]
+    ButtonButton $f.save [msgcat::mc {Save}] [list CATSaveVOTFile $varname]
+
     set var(apply) [ttk::button $f.apply \
 			-text [msgcat::mc {Retrieve}] \
 			-command "CATApply $varname 0"]
     set var(cancel) [ttk::button $f.cancel -text \
 			 [msgcat::mc {Cancel}] \
 			 -command "ARCancel $varname" -state disabled]
+    ttk::button $f.filter -text [msgcat::mc {Filter}] \
+	-command [list CATTable $varname]
     ttk::button $f.clear -text [msgcat::mc {Clear}] \
-	-command "CATOff $varname"
+	-command [list CATOff $varname]
     set var(samp) [ttk::button $f.samp \
 		       -text [msgcat::mc {SAMP}] \
 		       -command "SAMPSendTableLoadVotable {} $varname"]
+    ttk::button $f.plot -text [msgcat::mc {Plot}] \
+	-command [list CATPlot $varname]
     ttk::button $f.close -text [msgcat::mc {Close}] \
-	-command "CATDestroy $varname"
+	-command [list CATDestroy $varname]
 
-    pack $f.filter $f.apply $f.cancel $f.clear $f.samp $f.close \
-	-side left -expand true	-padx 2 -pady 4
+    pack $f.apply $f.cancel $f.filter $f.clear $f.samp $f.plot $f.close \
+	-side left -expand true -padx 2 -pady 4
 
     # Fini
     ttk::separator $w.stbl -orient horizontal
@@ -450,6 +470,9 @@ proc CATDialog {varname format catalog title action} {
 	sync {CATApply $varname 1}
 	none {}
     }
+
+    # return the actual varname
+    return $varname
 }
 
 proc CATDialogUpdate {varname} {
@@ -464,6 +487,33 @@ proc CATDialogUpdate {varname} {
 	puts stderr "CATDialogUpdate $varname"
     }
 
+    # do we have a db?
+    if {[CATValidDB $var(tbldb)]} {
+	$var(mb).file entryconfig [msgcat::mc {Filter}] -state normal
+	$var(mb).file entryconfig [msgcat::mc {Clear}] -state normal
+	$var(mb).file entryconfig [msgcat::mc {Plot}] -state normal
+	$var(mb).file entryconfig "[msgcat::mc {Display Header}]..." \
+	    -state normal
+	$var(mb).file entryconfig [msgcat::mc {Copy to Regions}] -state normal
+	$var(mb).file entryconfig "[msgcat::mc {Print}]..." -state normal
+
+	$var(top).buttons.filter configure -state normal
+	$var(top).buttons.clear configure -state normal
+	$var(top).buttons.plot configure -state normal
+    } else {
+	$var(mb).file entryconfig [msgcat::mc {Filter}] -state disabled
+	$var(mb).file entryconfig [msgcat::mc {Clear}] -state disabled
+	$var(mb).file entryconfig [msgcat::mc {Plot}] -state disabled
+	$var(mb).file entryconfig "[msgcat::mc {Display Header}]..." \
+	    -state disabled
+	$var(mb).file entryconfig [msgcat::mc {Copy to Regions}] -stat disabled
+	$var(mb).file entryconfig "[msgcat::mc {Print}]..." -state disabled
+
+	$var(top).buttons.filter configure -state disabled
+	$var(top).buttons.clear configure -state disabled
+	$var(top).buttons.plot configure -state disabled
+    }
+
     set m $var(mb).file.samp
     set ss [expr $ds9(menu,start)+2]
 
@@ -495,6 +545,7 @@ proc CATDialogUpdate {varname} {
 	# button
 	$var(samp) configure -state disabled
     }
+
 }
 
 proc CATAck {varname} {
@@ -592,6 +643,10 @@ proc CATCrosshair {varname} {
     upvar #0 $varname var
     global $varname
 
+    if {![$var(frame) has fits]} {
+	return
+    }
+
     if {[$var(frame) has wcs equatorial $var(system)]} {
 	set coord [$var(frame) get crosshair \
 		       $var(system) $var(sky) $var(skyformat)]
@@ -615,6 +670,17 @@ proc CATDestroy {varname} {
 	puts stderr "CATDestroy $varname"
     }
 
+    # stop timer if needed
+    if {$var(blink)} {
+	set var(blink) 0
+	after cancel [list CATSelectTimer $varname]
+    }
+
+    # unhighlite any makers
+    if {[$var(frame) has fits]} {
+	$var(frame) marker catalog $varname unhighlite
+    }
+
     upvar #0 $var(symdl) svar
     if [info exists svar(top)] {
 	if [winfo exists $svar(top)] {
@@ -637,6 +703,11 @@ proc CATDestroy {varname} {
 	set icat(cats) [lreplace $icat(cats) $i $i]
     }
 
+    # plot window?
+    if {$var(plot)} {
+	PlotDestroy $var(plot,var)
+    }
+
     ARDestroy $varname
 }
 
@@ -645,12 +716,19 @@ proc CATEdit {varname} {
     global $varname
     global $var(tbldb)
 
-    global current
+    if {![$var(frame) has fits]} {
+	return
+    }
 
     $var(frame) marker catalog unselect all
     $var(frame) marker catalog unhighlite all
 
-    CATPlot $varname
+    CATGenerate $varname
+
+    # regenerate the plot if needed
+    if {$var(plot)} {
+	CATPlotGenerate $varname
+    }
 
     if {$var(edit)} {
 	$var(tbl) configure \
@@ -762,7 +840,7 @@ proc CATKey {which key} {
 
     $which marker catalog key
     foreach rr $icat(key,update) {
-	eval "CATPlotUpdate [lindex $rr 0] [lindex $rr 1]"
+	eval "CATGenerateUpdate [lindex $rr 0] [lindex $rr 1]"
     }
 
     set icat(key) {}
@@ -799,13 +877,13 @@ proc CATPSPrint {varname} {
     global $varname
     global $var(tbldb)
 
-    global pr
+    global ps
 
     if {[PRPrintDialog]} { 
-	if {$pr(dest) == "file"} {
-	    catch {set ch [open "| cat > $pr(filename)" w]}
+	if {$ps(dest) == "file"} {
+	    catch {set ch [open "| cat > $ps(filename,txt)" w]}
 	} else {
-	    catch {set ch [open "| $pr(cmd)" w]}
+	    catch {set ch [open "| $ps(cmd)" w]}
 	}
 
 	if {$ch != {}} {
@@ -862,6 +940,10 @@ proc CATUpdate {varname} {
 	puts stderr "CATUpdate $varname"
     }
 
+    if {![$var(frame) has fits]} {
+	return
+    }
+
     if {[$var(frame) has wcs equatorial $var(system)]} {
 	set coord [$var(frame) get fits center \
 		       $var(system) $var(sky) $var(skyformat)]
@@ -961,12 +1043,18 @@ proc CATEditDialog {varname which db} {
     # file
     $mb add cascade -label [msgcat::mc {File}] -menu $mb.file
     menu $mb.file
-    $mb.file add command -label [msgcat::mc {Apply}] -command {set ed(ok) 1}
+    $mb.file add command -label [msgcat::mc {Apply}] \
+	-command {set ed(ok) 1}
+    $mb.file add command -label [msgcat::mc {Clear}] \
+	-command CATEditClear
     $mb.file add separator
-    $mb.file add command -label "[msgcat::mc {Load}]..." -command "CATEditLoad"
-    $mb.file add command -label "[msgcat::mc {Save}]..." -command "CATEditSave"
+    $mb.file add command -label "[msgcat::mc {Load}]..." \
+	-command CATEditLoad
+    $mb.file add command -label "[msgcat::mc {Save}]..." \
+	-command CATEditSave
     $mb.file add separator
-    $mb.file add command -label [msgcat::mc {Cancel}] -command {set ed(ok) 0}
+    $mb.file add command -label [msgcat::mc {Cancel}] \
+	-command {set ed(ok) 0}
 
     # edit
     $mb add cascade -label [msgcat::mc {Edit}] -menu $mb.edit
@@ -1120,8 +1208,9 @@ proc CATEditDialog {varname which db} {
     set f [ttk::frame $w.buttons]
     ttk::button $f.ok -text [msgcat::mc {OK}] -command {set ed(ok) 1} \
         -default active 
+    ttk::button $f.clear -text [msgcat::mc {Clear}] -command CATEditClear
     ttk::button $f.cancel -text [msgcat::mc {Cancel}] -command {set ed(ok) 0}
-    pack $f.ok $f.cancel -side left -expand true -padx 2 -pady 4
+    pack $f.ok $f.clear $f.cancel -side left -expand true -padx 2 -pady 4
 
     bind $w <Return> {set ed(ok) 1}
 
@@ -1150,6 +1239,12 @@ proc CATEditDialog {varname which db} {
     return $rr
 }
 
+proc CATEditClear {} {
+    global ed
+
+    $ed(text) delete 1.0 end
+}
+
 proc CATEditSave {} {
     global ed
 
