@@ -41,15 +41,31 @@ proc Error {message} {
     ProcessMessage error $message
 }
 
+proc Fatal {message} {
+    ProcessMessage fatal $message
+}
+
 proc ProcessMessage {level message} {
     global ds9
+    global pds9
 
     set ds9(msg,level) $level
     switch -- $ds9(msg,src) {
 	xpa -
 	hv -
 	samp {set ds9(msg) $message}
-	default {tk_messageBox -message $message -type ok -icon $level}
+	default {
+	    switch $ds9(msg,level) {
+		info -
+		warning -
+		error {
+		    if {$pds9(confirm)} {
+			tk_messageBox -message $message -type ok -icon $level
+		    }
+		}
+		fatal {tk_messageBox -message $message -type ok -icon error}
+	    }
+	}
     }
 }
 
@@ -58,14 +74,33 @@ proc ProcessMessage {level message} {
 # XPA, HV, and SAMP will have already seen any problems
 proc ErrorTimer {} {
     global ds9
+    global pds9
 
     if {$ds9(msg) != {}} {
-	tk_messageBox -message $ds9(msg) -type ok -icon $ds9(msg,level)
+	switch $ds9(msg,level) {
+	    info -
+	    warning -
+	    error {
+		if {$pds9(confirm)} {
+		    tk_messageBox -message $ds9(msg) -type ok -icon $ds9(msg,level)
+		}
+	    }
+	    fatal {
+		# something really bad has happened. BAIL!
+		tk_messageBox -message $ds9(msg) -type ok -icon error
+		return
+	    }
+	}
 	InitError tcl
     }
 
     # set again
-    after $ds9(msg,timeout) ErrorTimer
+    switch $ds9(msg,level) {
+	info -
+	warning -
+	error {after $ds9(msg,timeout) ErrorTimer}
+	fatal {}
+    }
 }
 
 
