@@ -162,6 +162,10 @@ proc CreateNameNumberFrame {which type} {
 	rgb {}
 	3d {
 	    $ds9(next) 3d method $pthreed(method)
+	    $ds9(next) 3d border $pthreed(border)
+	    $ds9(next) 3d border color $pthreed(border,color)
+	    $ds9(next) 3d compass $pthreed(compass)
+	    $ds9(next) 3d compass color $pthreed(compass,color)
 	    $ds9(next) 3d highlite $pthreed(highlite)
 	    $ds9(next) 3d highlite color $pthreed(highlite,color)
 	}
@@ -2377,6 +2381,7 @@ proc ProcessLockCmd {varname iname} {
     global bin
     global scale
     global colorbar
+    global smooth
 
     # we need to be realized
     ProcessRealizeDS9
@@ -2445,6 +2450,16 @@ proc ProcessLockCmd {varname iname} {
 	    }
 	    LockColorCurrent
 	}
+	smooth {
+	    incr i
+	    if {!([string range [lindex $var $i] 0 0] == "-")} {
+		set smooth(lock) [FromYesNo [lindex $var $i]]
+	    } else {
+		set smooth(lock) 1
+		incr i -1
+	    }
+	    LockSmoothCurrent
+	}
     }
 }
 
@@ -2456,6 +2471,7 @@ proc ProcessSendLockCmd {proc id param} {
     global bin
     global scale
     global colorbar
+    global smooth
 
     switch -- [lindex $param 0] {
 	frame -
@@ -2473,6 +2489,7 @@ proc ProcessSendLockCmd {proc id param} {
 	colormap -
 	colorbar -
 	colorbars {$proc $id [ToYesNo $colorbar(lock)]}
+	smooth {$proc $id [ToYesNo $smooth(lock)]}
     }
 }
 
@@ -2509,6 +2526,7 @@ proc ProcessMatchCmd {varname iname} {
 	colormap -
 	colorbar -
 	colorbars {MatchColorCurrent}
+	smooth {MatchSmoothCurrent}
     }
 }
 
