@@ -99,7 +99,8 @@ proc GridUpdate {} {
 
 	if {$grid(view) && [$current(frame) has fits]} {
 	    $current(frame) grid create $grid(system) $grid(sky) \
-		$grid(skyformat) $grid(type) [GridBuildOptions]
+		$grid(skyformat) $grid(type) \
+		[GridBuildOptions] "\"[array get grid]\""
 	} else {
 	    $current(frame) grid delete
 	}
@@ -439,179 +440,6 @@ proc GridBuildOptions {} {
     return $opt
 }
 
-proc GridParseOptions {opt} {
-    global grid
-    global current
-    global debug
-
-    if {$debug(tcl,grid)} {
-	puts stderr "GridParseOptions"
-	puts stderr "$opt"
-    }
-
-    # defaults
-    set grid(textlab,def1) 1
-    set grid(textlab,def2) 1
-
-    foreach oo [split $opt ,] {
-	foreach {key value} [split $oo {=}] {
-	    switch -- [string trim $key] {
-
-		Grid {set grid(grid) $value}
-		Colour(grid) {set grid(grid,color) [GridAst2Color $value]}
-		Width(grid) {set grid(grid,width) $value}
-		Style(grid) {set grid(grid,style) $value}
-
-		DrawAxes {set grid(axes) $value}
-		Colour(axes) {set grid(axes,color) [GridAst2Color $value]}
-		Width(axes) {set grid(axes,width) $value}
-		Style(axes) {set grid(axes,style) $value}
-
-		Format(1) {
-		    if {[GridDefaultFormat1] != $value} {
-			set grid(format1) $value
-		    } else {
-			set grid(format1) {}
-		    }
-		}
-		Format(2) {
-		    if {[GridDefaultFormat2] != $value} {
-			set grid(format2) $value
-		    } else {
-			set grid(format2) {}
-		    }
-		}
-
-		MajTickLen {}
-		MinTick(1) {set grid(tick) $value}
-		MinTick(2) {}
-		MinTick(3) {}
-		Colour(ticks) {set grid(tick,color) [GridAst2Color $value]}
-		Width(ticks) {set grid(tick,width) $value}
-		Style(ticks) {set grid(tick,style) $value}
-
-		Border {set grid(border) $value}
-		Colour(border) {set grid(border,color) [GridAst2Color $value]}
-		Width(border) {set grid(border,width) $value}
-		Style(border) {set grid(border,style) $value}
-
-		Labelling {set grid(axes,type) $value}
-		LabelUp {
-		    switch -- [$current(frame) get type] {
-			base -
-			rgb {set grid(numlab,vertical) $value}
-			3d {}
-		    }
-		}
-
-		NumLab {set grid(numlab) $value}
-		Font(numlab) {
-		    GridAst2Font $value grid(numlab,font) \
-			grid(numlab,weight) grid(numlab,slant)
-		}
-		Size(numlab) {set grid(numlab,size) $value}
-		Colour(numlab) {set grid(numlab,color) [GridAst2Color $value]}
-
-		TextLab -
-		TextLab(1) {
-		    switch -- $grid(type) {
-			analysis {}
-			publication {set grid(textlab) $value}
-		    }
-		}
-		TextLab(2) {}
-		Label(1) {
-		    set grid(textlab,text1) $value
-		    set grid(textlab,def1) 0
-		}
-		Label(2) {
-		    set grid(textlab,text2) $value
-		    set grid(textlab,def2) 0
-		}
-		Font(textlab) {
-		    GridAst2Font $value grid(textlab,font) \
-			grid(textlab,weight) grid(textlab,slant)
-		}
-		Size(textlab) {set grid(textlab,size) $value}
-		Colour(textlab) {set grid(textlab,color) [GridAst2Color $value]}
-
-		DrawTitle {
-		    switch -- $grid(type) {
-			analysis {}
-			publication {
-			    switch -- [$current(frame) get type] {
-				base -
-				rgb {set grid(title) $value}
-				3d {}
-			    }
-			}
-		    }
-		}
-		Title {set titleFont $value}
-		Font(title) {
-		    GridAst2Font $value grid(title,font) \
-			grid(title,weight) grid(title,slant)
-		}
-		Size(title) {set grid(title,size) $value}
-		Colour(title) {set grid(title,color) [GridAst2Color $value]}
-
-		Gap(1) {
-		    if {($value != {}) && ($grid(grid,gapunit1) == "degrees")} {
-			set grid(grid,gap1) [expr 180.*$value/3.14159]
-		    } else {
-			set grid(grid,gap1) $value
-		    }
-		}
-		Gap(2) {
-		    if {($value != {}) && ($grid(grid,gapunit2) == "degrees")} {
-			set grid(grid,gap2) [expr 180.*$value/3.14159]
-		    } else {
-			set grid(grid,gap2) $value
-		    }
-		}
-		Gap(3) {
-		    switch -- [$current(frame) get type] {
-			base -
-			rgb {}
-			3d {set grid(grid,gap3) $value}
-		    }
-		}
-
-		NumLabGap(1) {}
-		NumLabGap(2) {}
-		TextLabGap(1) {}
-		TextLabGap(2) {}
-		TitleGap {}
-
-		Edge(1) {}
-		Edge(2) {}
-		RootCorner {
-		    switch -- [$current(frame) get type] {
-			base -
-			rgb {}
-			3d {
-			    switch -- $grid(type) {
-				analysis {}
-				publication {set grid(axes,origin) $value}
-			    }
-			}
-		    }
-		}
-
-		Norm(1) {}
-		Norm(2) {}
-		Norm(3) {}
-
-		default {
-		    if {$debug(tcl,grid)} {
-			puts stderr "Unknown keyword: $key=$value"
-		    }
-		}
-	    }
-	}
-    }
-}
-
 proc GridAst2Color {ast} {
     switch -- $ast {
 	0 {return {black}}
@@ -1039,16 +867,14 @@ proc UpdateGridMenu {} {
 	set grid(skyformat) [lindex $ll 2]
 	set grid(type) [lindex $ll 3]
 
-#	GridParseOptions [$current(frame) get grid option]
-	GridParseOptions [$current(frame) get grid option]
-
-	if {0} {
-	foreach {key value} [array get gridd] {
-	    if {$grid($key) != $gridd($key)} {
-		puts stderr "grid($key)=$grid($key) gridd($key)=$gridd($key)"
-	    }
-	}
+	# fix for grids create with old backup command
+	if {[$current(frame) get grid var] == {}} {
+	    $current(frame) grid delete
+	    $current(frame) grid create $grid(system) $grid(sky) \
+		$grid(skyformat) $grid(type) \
+		[GridBuildOptions] "\"[array get grid]\""
 	}
+	array set grid [$current(frame) get grid var]
     } else {
 	# can be changed by wcs
 	SetCoordSystem grid system sky skyformat
@@ -1072,69 +898,71 @@ proc UpdateGridDialog {} {
     if {[winfo exists $igrid(top)]} {
 	set f $igrid(top).label
 	set g $igrid(top).param
-	switch -- [$current(frame) get type] {
-	    base -
-	    rgb {
-		$mb entryconfig [msgcat::mc {Labels}] -state normal
-		$mb entryconfig [msgcat::mc {Title}] -state normal
-		$mb.type entryconfig [msgcat::mc {Interior Numerics}] \
-		    -state normal
-		$mb.type entryconfig [msgcat::mc {Exterior Numerics}] \
-		    -state normal
-		$mb.type entryconfig [msgcat::mc {Vertical Text}] \
-		    -state normal
-		$mb.axes entryconfig [msgcat::mc {Origin}] \
-		    -state disable
-
-		$f.label configure -state normal
-		$f.title configure -state normal
-		$f.default configure -state normal
-		$f.label1 configure -state normal
-		$f.title1 configure -state normal
-		$f.default1 configure -state normal
-		$f.label2 configure -state normal
-		$f.title2 configure -state normal
-		$f.default2 configure -state normal
-
-		$g.lspace configure -state normal
-		$g.spacet configure -state normal
-		$g.tspace1 configure -state normal
-		$g.tspace2 configure -state normal
-
-		grid forget $g.title3 $g.nspace3 $g.format3 $g.gap3 $g.gapunit3
-	    }
-	    3d {
-		$mb entryconfig [msgcat::mc {Labels}] -state disabled
-		$mb entryconfig [msgcat::mc {Title}] -state disabled
-		$mb.type entryconfig [msgcat::mc {Interior Numerics}] \
-		    -state disabled
-		$mb.type entryconfig [msgcat::mc {Exterior Numerics}] \
-		    -state disabled
-		$mb.type entryconfig [msgcat::mc {Vertical Text}] \
-		    -state disabled
-		$mb.axes entryconfig [msgcat::mc {Origin}] -state normal
-
-		$f.label configure -state disabled
-		$f.title configure -state disabled
-		$f.default configure -state disabled
-		$f.label1 configure -state disabled
-		$f.title1 configure -state disabled
-		$f.default1 configure -state disabled
-		$f.label2 configure -state disabled
-		$f.title2 configure -state disabled
-		$f.default2 configure -state disabled
-
-		$g.lspace configure -state disabled
-		$g.spacet configure -state disabled
-		$g.tspace1 configure -state disabled
-		$g.tspace2 configure -state disabled
-
-		grid $g.title3 x $g.nspace3 $g.format3 $g.gap3 $g.gapunit3 \
-		    -padx 2 -pady 2 -sticky w
-	    }
-	}
 
 	if {$current(frame) != {}} {
+	    switch -- [$current(frame) get type] {
+		base -
+		rgb {
+		    $mb entryconfig [msgcat::mc {Labels}] -state normal
+		    $mb entryconfig [msgcat::mc {Title}] -state normal
+		    $mb.type entryconfig [msgcat::mc {Interior Numerics}] \
+			-state normal
+		    $mb.type entryconfig [msgcat::mc {Exterior Numerics}] \
+			-state normal
+		    $mb.type entryconfig [msgcat::mc {Vertical Text}] \
+			-state normal
+		    $mb.axes entryconfig [msgcat::mc {Origin}] \
+			-state disable
+
+		    $f.label configure -state normal
+		    $f.title configure -state normal
+		    $f.default configure -state normal
+		    $f.label1 configure -state normal
+		    $f.title1 configure -state normal
+		    $f.default1 configure -state normal
+		    $f.label2 configure -state normal
+		    $f.title2 configure -state normal
+		    $f.default2 configure -state normal
+
+		    $g.lspace configure -state normal
+		    $g.spacet configure -state normal
+		    $g.tspace1 configure -state normal
+		    $g.tspace2 configure -state normal
+
+		    grid forget $g.title3 $g.nspace3 $g.format3 $g.gap3 \
+			$g.gapunit3
+		}
+		3d {
+		    $mb entryconfig [msgcat::mc {Labels}] -state disabled
+		    $mb entryconfig [msgcat::mc {Title}] -state disabled
+		    $mb.type entryconfig [msgcat::mc {Interior Numerics}] \
+			-state disabled
+		    $mb.type entryconfig [msgcat::mc {Exterior Numerics}] \
+			-state disabled
+		    $mb.type entryconfig [msgcat::mc {Vertical Text}] \
+			-state disabled
+		    $mb.axes entryconfig [msgcat::mc {Origin}] -state normal
+
+		    $f.label configure -state disabled
+		    $f.title configure -state disabled
+		    $f.default configure -state disabled
+		    $f.label1 configure -state disabled
+		    $f.title1 configure -state disabled
+		    $f.default1 configure -state disabled
+		    $f.label2 configure -state disabled
+		    $f.title2 configure -state disabled
+		    $f.default2 configure -state disabled
+
+		    $g.lspace configure -state disabled
+		    $g.spacet configure -state disabled
+		    $g.tspace1 configure -state disabled
+		    $g.tspace2 configure -state disabled
+
+		    grid $g.title3 x $g.nspace3 $g.format3 $g.gap3 $g.gapunit3 \
+			-padx 2 -pady 2 -sticky w
+		}
+	    }
+
 	    set grid(frame) $current(frame)
 	    if {[$current(frame) has fits]} {
 		CoordMenuEnable $igrid(mb).coord grid system 1 sky skyformat
@@ -1283,6 +1111,8 @@ proc GridDefaultFormat2 {} {
 }
 
 proc GridBackup {ch which} {
+    global grid
+
     if [$which has grid] {
 	set ll  [$which get grid]
 	set system [lindex $ll 0]
@@ -1290,8 +1120,9 @@ proc GridBackup {ch which} {
 	set skyformat [lindex $ll 2]
 	set type [lindex $ll 3]
 	set opts [$which get grid option]
+	set vars [array get grid]
 
-	puts $ch "$which grid create $system $sky $skyformat $type \{\"$opts\"\}"
+	puts $ch "$which grid create $system $sky $skyformat $type \{\"$opts\"\} \{\"$vars\"\}"
     }
 }
 
