@@ -133,10 +133,6 @@ proc InitCanvas {} {
 	win32 {}
     }
 
-    bind $ds9(canvas) <Motion> [list CursorCanvas %x %y]
-    bind $ds9(image) <Enter> [list CursorCanvas %x %y]
-    bind $ds9(image) <Leave> [list CursorCanvas -1 -1]
-
     bind $ds9(canvas) <Configure> [list ConfigureView]
     switch $ds9(wm) {
 	x11 -
@@ -181,18 +177,6 @@ proc InitCanvas {} {
     bind $ds9(canvas) <f> {ToggleBindEvents}
 }
 
-proc CursorCanvas {x y} {
-    global ds9
-
-    global debug
-    if {$debug(tcl,events)} {
-	puts stderr "CursorCanvas $x $y"
-    }
-
-    set ds9(x) $x
-    set ds9(y) $y
-}
-
 proc Button3Canvas {x y} {
     global ds9
 
@@ -796,7 +780,8 @@ proc ProcessHeightCmd {varname iname} {
     upvar $iname i
 
     # we need to be realized
-    ProcessRealizeDS9
+    # can't use ProcessRealize
+    RealizeDS9
 
     global canvas
     set canvas(height) [lindex $var $i]
@@ -813,7 +798,8 @@ proc ProcessWidthCmd {varname iname} {
     upvar $iname i
 
     # we need to be realized
-    ProcessRealizeDS9
+    # can't use ProcessRealize
+    RealizeDS9
 
     global canvas
     set canvas(width) [lindex $var $i]
