@@ -61,6 +61,7 @@ proc MarkerDef {} {
     unset pmarker(skyformat)
     unset pmarker(strip)
 
+    set pmarker(dformat) degrees
     set pmarker(circle,radius) 20
     set pmarker(annulus,inner) 15
     set pmarker(annulus,outer) 30
@@ -564,9 +565,8 @@ proc MarkerDouble {which x y} {
 		    set vvarname proj${id}${which}
 		    upvar #0 $vvarname vvar
 		    global $vvarname
-		    if {[APPing $vvarname]} {
-			APRaise $vvarname
-		    }
+
+		    PlotRaise $vvarname
 		}
 	    }
 	}
@@ -1373,7 +1373,10 @@ proc ProcessRegionsCmd {varname iname sock fn} {
 		    set marker(centroid,iteration) [lindex $var $i]
 		    MarkerCentroidIteration
 		}
-		default {MarkerCentroid}
+		default {
+		    incr i -1
+		    MarkerCentroid
+		}
 	    }
 	}
 	autocentroid {
