@@ -10,16 +10,6 @@ proc FileMainMenu {} {
     global ds9
 
     menu $ds9(mb).file 
-    switch $ds9(wm) {
-	x11 -
-	win32 {
-	    $ds9(mb).file add command \
-		-label "[msgcat::mc {About SAOImage DS9}]..." \
-		-command AboutBox
-	    $ds9(mb).file add separator
-	}
-	aqua {}
-    }
     $ds9(mb).file add command -label "[msgcat::mc {Open}]..." \
 	-command OpenFits -accelerator "${ds9(ctrl)}O"
     $ds9(mb).file add cascade -label [msgcat::mc {Open Other}] \
@@ -38,7 +28,7 @@ proc FileMainMenu {} {
     $ds9(mb).file add cascade -label [msgcat::mc {Preserve During Load}] \
 	-menu $ds9(mb).file.preserve
     $ds9(mb).file add separator
-    $ds9(mb).file add command -label "[msgcat::mc {Display Fits Header}]..." \
+    $ds9(mb).file add command -label "[msgcat::mc {Display Header}]..." \
 	-command DisplayHeaderMenu 
     $ds9(mb).file add separator
     $ds9(mb).file add cascade -label [msgcat::mc {XPA}] \
@@ -239,7 +229,6 @@ proc ButtonsFileDef {} {
     global pbuttons
 
     array set pbuttons {
-	file,about 1
 	file,open 1
 	file,save 1
 	file,export 0
@@ -265,8 +254,6 @@ proc CreateButtonsFile {} {
 
     ttk::frame $ds9(buttons).file
 
-    ButtonButton $ds9(buttons).file.about \
-	[string tolower [msgcat::mc {About}]] AboutBox
     ButtonButton $ds9(buttons).file.open \
 	[string tolower [msgcat::mc {Open}]] OpenFits
 
@@ -325,7 +312,6 @@ proc CreateButtonsFile {} {
 	[string tolower [msgcat::mc {Exit}]] QuitDS9
 
     set buttons(file) "
-        $ds9(buttons).file.about pbuttons(file,about)
         $ds9(buttons).file.open pbuttons(file,open)
         $ds9(buttons).file.save pbuttons(file,save)
         $ds9(buttons).file.export pbuttons(file,export)
@@ -353,9 +339,6 @@ proc PrefsDialogButtonbarFile {f} {
     
     set m $f.menu
     menu $m
-    $m add checkbutton -label "[msgcat::mc {About SAOImage DS9}]..." \
-	-variable pbuttons(file,about) -command {UpdateButtons buttons(file)}
-    $m add separator
     $m add checkbutton -label "[msgcat::mc {Open}]..." \
 	-variable pbuttons(file,open) -command {UpdateButtons buttons(file)}
 
@@ -370,7 +353,7 @@ proc PrefsDialogButtonbarFile {f} {
     $m add checkbutton -label "[msgcat::mc {Create Movie}]..." \
 	-variable pbuttons(file,movie) -command {UpdateButtons buttons(file)}
     $m add separator
-    $m add checkbutton -label "[msgcat::mc {Display Fits Header}]..." \
+    $m add checkbutton -label "[msgcat::mc {Display Header}]..." \
 	-variable pbuttons(file,header) -command {UpdateButtons buttons(file)}
     $m add separator
     $m add cascade -label [msgcat::mc {SAMP}] -menu $m.samp
@@ -461,7 +444,7 @@ proc UpdateFileMenu {} {
 	if {[$current(frame) has fits]} {
 	    $mm entryconfig "[msgcat::mc {Save}]..." -state normal
 	    $mm entryconfig "[msgcat::mc {Export}]..." -state normal
-	    $mm entryconfig "[msgcat::mc {Display Fits Header}]..." \
+	    $mm entryconfig "[msgcat::mc {Display Header}]..." \
 		-state normal
 
 	    $bb.save configure -state normal
@@ -469,7 +452,7 @@ proc UpdateFileMenu {} {
 	} else {
 	    $mm entryconfig "[msgcat::mc {Save}]..." -state disabled
 	    $mm entryconfig "[msgcat::mc {Export}]..." -state disabled
-	    $mm entryconfig "[msgcat::mc {Display Fits Header}]..." \
+	    $mm entryconfig "[msgcat::mc {Display Header}]..." \
 		-state disabled
 
 	    $bb.save configure -state disabled
@@ -561,7 +544,7 @@ proc UpdateFileMenu {} {
 	    $bb.samptable configure -state disabled
 	}
     } else {
-	$mm entryconfig "[msgcat::mc {Display Fits Header}]..." \
+	$mm entryconfig "[msgcat::mc {Display Header}]..." \
 	    -state disabled
 
 	$bb.header configure -state disabled
