@@ -614,21 +614,22 @@ proc MatchFrame {which sys} {
 	    }
 	}
 	wcs {
-	    set ss [lindex [$which get wcs] 0]
-	    if {[$which has wcs $ss]} {
+	    set www [$which get wcs]
+	    set sys [lindex $www 0]
+	    set sky [lindex $www 1]
+	    if {[$which has wcs $sys]} {
 		set wcs(align) 1
 		$which wcs align 1
 		set align [$which get wcs align pointer]
-
-		set pan [$which get cursor $ss FK5 scientific]
+		set pan [$which get cursor $sys FK5 scientific]
 		set zoom [$which get zoom]
 		set rotate [$which get rotate]
 		set orient [$which get orient]
 
 		foreach ff $ds9(frames) {
 		    if {$ff != $which} {
-			if {[$ff has wcs $ss]} {
-			    $ff pan to $ss FK5 $pan
+			if {[$ff has wcs $sys]} {
+			    $ff pan to $sys FK5 $pan
 			    $ff zoom to $zoom
 			    $ff rotate to $rotate
 			    $ff orient $orient
