@@ -372,10 +372,40 @@ proc FixPrefs {version} {
 	    FixPrefs6.2to7.0
 	}
 	7.0 {
+	    FixPrefs7.0to7.1
 	}
     }
 }
 
+proc FixPrefs7.0to7.1 {} {
+    global pap
+
+    if {[info exists pap(grid)]} {
+	set pap(grid,x) $pap(grid)
+	set pap(grid,y) $pap(grid)
+	switch $pap(grid,log) {
+	    linearlinear {
+		set pap(grid,xlog) 0
+		set pap(grid,ylog) 0
+	    }
+	    linearlog {
+		set pap(grid,xlog) 0
+		set pap(grid,ylog) 1
+	    }
+	    loglinear {
+		set pap(grid,xlog) 1
+		set pap(grid,ylog) 0
+	    }
+	    loglog {
+		set pap(grid,xlog) 1
+		set pap(grid,ylog) 1
+	    }
+	}
+	unset pap(grid)
+	unset pap(grid,log)
+    }
+}
+
 proc FixPrefs6.2to7.0 {} {
     global ps
     global pps
