@@ -207,7 +207,7 @@ proc SAMPSendImageLoadFits {id} {
 
     # save current frame
     set fn [tmpnam ds9samp {.fits}]
-    $current(frame) save fits image file "\{$fn\}"
+    catch {$current(frame) save fits image file "\{$fn\}"}
 
     # name to use
     set fnb [$current(frame) get fits file name root base]
@@ -278,7 +278,7 @@ proc SAMPSendTableLoadFits {id} {
 
     # save current frame
     set fn [tmpnam ds9samp {.fits}]
-    $current(frame) save fits table file "\{$fn\}"
+    catch {$current(frame) save fits table file "\{$fn\}"}
 
     # name to use
     set fnb [$current(frame) get fits file name root base]
@@ -388,6 +388,7 @@ proc SAMPSendTableHighlightRow {id varname row} {
     global sampmap
     global sampmap2
 
+    # row starts at 1
     upvar #0 $varname var
     global $varname
 
@@ -402,7 +403,7 @@ proc SAMPSendTableHighlightRow {id varname row} {
 
     catch {unset sampmap2}
     set sampmap2(table-id) "string [XMLQuote $samp(ocat,$varname)]"
-    set sampmap2(row) "string [XMLQuote $row]"
+    set sampmap2(row) "string [XMLQuote [expr $row-1]]"
 
     set param1 [list "string $samp(private)"]
     if {$id != {}} {
@@ -430,6 +431,7 @@ proc SAMPSendTableSelectRowList {id varname rows} {
     global sampmap
     global sampmap2
 
+    # rows start at 1
     upvar #0 $varname var
     global $varname
 
@@ -446,7 +448,7 @@ proc SAMPSendTableSelectRowList {id varname rows} {
     set sampmap2(table-id) "string [XMLQuote $samp(ocat,$varname)]"
     set ss {}
     foreach rr $rows {
-	lappend ss "string $rr"
+	lappend ss "string [expr $rr-1]"
     }
     set sampmap2(row-list) [list array $ss]
 
@@ -1279,7 +1281,7 @@ proc SAMPRcvdTableHighlightRow {varname} {
 
     if {$tabid != {} && $row != {}} {
 	if [info exists samp(icat,$tabid)] {
-	    CATSelectRows $samp(icat,$tabid) [expr $row+1]
+	    CATSelectRows $samp(icat,$tabid) samp [expr $row+1]
 	}
     }
 }
@@ -1325,7 +1327,7 @@ proc SAMPRcvdTableSelectRowList {varname} {
 
     if {$tabid != {} && [llength $rowlist] != 0} {
 	if [info exists samp(icat,$tabid)] {
-	    CATSelectRows $samp(icat,$tabid) $rowlist
+	    CATSelectRows $samp(icat,$tabid) samp $rowlist
 	}
     }
 }
@@ -1469,9 +1471,10 @@ proc SAMPRcvdDS9SetReply {msgid} {
     if {$errorInfo != {} || $ds9(msg) != {}} {
 	if {$ds9(msg) != {}} {
 	    switch $ds9(msg,level) {
-		info {SAMPReply $msgid OK $ds9(msg)}
-		warning -
-		error {SAMPReply $msgid ERROR {} {} $ds9(msg)}
+		info -
+		warning {SAMPReply $msgid OK $ds9(msg)}
+		error -
+		fatal {SAMPReply $msgid ERROR {} {} $ds9(msg)}
 	    }
 	} else {
 	    SAMPReply $msgid ERROR {} {} [lindex [split $errorInfo "\n"] 0]
@@ -1535,9 +1538,10 @@ proc SAMPRcvdDS9GetReply {msgid msg {fn {}}} {
     if {$errorInfo != {} || $ds9(msg) != {}} {
 	if {$ds9(msg) != {}} {
 	    switch $ds9(msg,level) {
-		info {SAMPReply $msgid OK $ds9(msg)}
-		warning -
-		error {SAMPReply $msgid ERROR {} {} $ds9(msg)}
+		info -
+		warning {SAMPReply $msgid OK $ds9(msg)}
+		error -
+		fatal {SAMPReply $msgid ERROR {} {} $ds9(msg)}
 	    }
 	} else {
 	    SAMPReply $msgid ERROR {} {} [lindex [split $errorInfo "\n"] 0]
