@@ -295,7 +295,6 @@ proc ScaleDialog {} {
     set f [ttk::frame $w.param]
 
     # Graph
-    set dscale(width) 1
     set dscale(hist) [blt::barchart $f.chart \
 			  -width 500 -height 200 \
 			  -title [msgcat::mc {Pixel Distribution}] \
@@ -313,8 +312,7 @@ proc ScaleDialog {} {
     blt::vector create $dscale(xdata) $dscale(ydata)
     $dscale(hist) element create bar1 \
 	-xdata $dscale(xdata) -ydata $dscale(ydata) \
-	-relief flat -foreground #000001 -background #000001 \
-	-barwidth $dscale(width)
+	-relief flat -foreground #000001 -background #000001
 
     # Cut Lines
     $dscale(hist) marker bind min <B1-Motion> \
@@ -474,6 +472,7 @@ proc UpdateScaleDialog {} {
 
 	    set stepsize [format "%.4g" \
 			      [expr ($dscale(minmin)-$dscale(minmax))/4.]]
+
 	    $dscale(hist) xaxis configure -hide no -stepsize $stepsize
 	    $dscale(hist) yaxis configure -hide no -min 1
 
@@ -549,11 +548,19 @@ proc ScaleXAxisDialog {} {
 
     switch -- $scale(xaxis) { 
 	full {
+	    set width [expr abs(1.0*($dscale(minmax)-$dscale(minmin))/ \
+				    [$dscale(xdata) length])]
+	    $dscale(hist) element configure bar1 -barwidth $width
+
 	    $dscale(hist) xaxis configure \
-		-min [expr $dscale(minmin)-$dscale(width)] \
-		-max [expr $dscale(minmax)+$dscale(width)]
+		-min [expr $dscale(minmin)-$width] \
+		-max [expr $dscale(minmax)+$width]
 	}
 	current {
+	    set width [expr abs(1.0*($dscale(max)-$dscale(min))/ \
+				    [$dscale(xdata) length])]
+	    $dscale(hist) element configure bar1 -barwidth $width
+
 	    if {[expr abs($dscale(max)-$dscale(min)) > 0]} {
 		set diff [expr $dscale(max)-$dscale(min)]
 		set per .10
