@@ -28,21 +28,6 @@ proc CurrentDef {} {
     set pcurrent(orient) $current(orient)
 }
 
-proc HTTPDef {} {
-    global ihttp
-    global phttp
-
-    set ihttp(timeout) 240000
-
-    # prefs only
-    set phttp(proxy) 0
-    set phttp(proxy,host) {}
-    set phttp(proxy,port) {}
-    set phttp(auth) 0
-    set phttp(auth,user) {}
-    set phttp(auth,passwd) {}
-}
-
 proc CursorDef {} {
     global icursor
 
@@ -711,7 +696,7 @@ proc AboutBox {} {
 
     # Param
     set f [frame $w.param -background white]
-    canvas $f.c -background white -height 550 -width 400
+    canvas $f.c -background white -height 450 -width 550
     pack $f.c -fill both -expand true
     
     # can't use -file for zvfs
@@ -726,7 +711,7 @@ proc AboutBox {} {
     unset dd
 
     $f.c create image 0 0 -image $ed(sun) -anchor nw
-    $f.c create text 120 22 -text $help(about) -anchor nw
+    $f.c create text 120 22 -text $help(about) -anchor nw -width 400
 
     # Buttons
     set f [ttk::frame $w.buttons]
