@@ -28,7 +28,6 @@ proc UpdateWCS {} {
     # frame
     if {$current(frame) != {}} {
 	$current(frame) wcs $wcs(system) $wcs(sky) $wcs(skyformat)
-	$current(frame) panner wcs $wcs(system) $wcs(sky)
 
 	AlignWCSFrame
 	set wcs(frame) $current(frame)
@@ -174,18 +173,38 @@ proc WCSDialog {} {
     set tt [ttk::notebook $w.param]
     set base [ttk::frame $tt.base]
     set pv00 [ttk::frame $tt.pv00]
-    set pv10 [ttk::frame $tt.pv10]
-    set pv20 [ttk::frame $tt.pv20]
-    set pv30 [ttk::frame $tt.pv30]
-    set pv40 [ttk::frame $tt.pv40]
+    set pv12 [ttk::frame $tt.pv12]
+    set pv24 [ttk::frame $tt.pv24]
+    set ab0 [ttk::frame $tt.ab0]
+    set ab2 [ttk::frame $tt.ab2]
+    set ab4 [ttk::frame $tt.ab4]
+    set apbp0 [ttk::frame $tt.apbp0]
+    set apbp2 [ttk::frame $tt.apbp2]
+    set apbp4 [ttk::frame $tt.apbp4]
     $tt add $base -text {Keyword}
     $tt add $pv00 -text {PVi_00}
-    $tt add $pv10 -text {PVi_10}
-    $tt add $pv20 -text {PVi_20}
-    $tt add $pv30 -text {PVi_30}
-    $tt add $pv40 -text {PVi_40}
+    $tt add $pv12 -text {PVi_12}
+    $tt add $pv24 -text {PVi_24}
+    $tt add $ab0 -text {A_0}
+    $tt add $ab2 -text {A_2}
+    $tt add $ab4 -text {A_4}
+    $tt add $apbp0 -text {AP_0}
+    $tt add $apbp2 -text {AP_2}
+    $tt add $apbp4 -text {AP_4}
     $tt select $base
 
+    label $base.tmjdobs -text "MJD-OBS"
+    ttk::entry $base.mjdobs -textvariable dwcs(mjd-obs) -width 14
+
+    label $base.tdateobs -text "DATE-OBS"
+    ttk::entry $base.dateobs -textvariable dwcs(date-obs) -width 14
+
+    label $base.tdate -text "DATE"
+    ttk::entry $base.date -textvariable dwcs(date) -width 14
+
+    label $base.tepoch -text "EPOCH"
+    ttk::entry $base.epoch -textvariable dwcs(epoch) -width 14
+
     foreach aa {{} a b c d e f g h i j k l m n o p q r s t u v w x y z} {
 	set bb [string toupper $aa]
 
@@ -193,6 +212,22 @@ proc WCSDialog {} {
 	ttk::entry $base.wcsname${aa} \
 	    -textvariable dwcs(wcsname${aa}) -width 14
 
+	label $base.tradesys${aa} -text "RADESYS${bb}"
+	ttk::entry $base.radesys${aa} \
+	    -textvariable dwcs(radesys${aa}) -width 14
+
+	label $base.tequinox${aa} -text "EQUINOX${bb}"
+	ttk::entry $base.equinox${aa} \
+	    -textvariable dwcs(equinox${aa}) -width 14
+
+	ttk::label $base.tlatpole${aa} -text "LATPOLE${bb}"
+	ttk::entry $base.latpole${aa} \
+	    -textvariable dwcs(latpole${aa}) -width 14
+
+	ttk::label $base.tlonpole${aa} -text "LONPOLE${bb}"
+	ttk::entry $base.lonpole${aa} \
+	    -textvariable dwcs(lonpole${aa}) -width 14
+
 	for {set ii 1} {$ii<=2} {incr ii} {
 	    ttk::label $base.tctype${ii}${aa} -text "CTYPE${ii}${bb}"
 	    ttk::entry $base.ctype${ii}${aa} \
@@ -226,39 +261,124 @@ proc WCSDialog {} {
 		    -textvariable dwcs(pc${ii}_${jj}${aa}) -width 14
 	    }
 
-	    for {set mm 0} {$mm<10} {incr mm} {
+	    for {set mm 0} {$mm<12} {incr mm} {
 		ttk::label $pv00.tpv${ii}_${mm}${aa} \
 		    -text "PV${ii}_${mm}${bb}"
 		ttk::entry $pv00.pv${ii}_${mm}${aa} \
 		    -textvariable dwcs(pv${ii}_${mm}${aa}) -width 14
 	    }
-	    for {set mm 10} {$mm<20} {incr mm} {
-		ttk::label $pv10.tpv${ii}_${mm}${aa} \
+	    for {set mm 12} {$mm<24} {incr mm} {
+		ttk::label $pv12.tpv${ii}_${mm}${aa} \
 		    -text "PV${ii}_${mm}${bb}"
-		ttk::entry $pv10.pv${ii}_${mm}${aa} \
+		ttk::entry $pv12.pv${ii}_${mm}${aa} \
 		    -textvariable dwcs(pv${ii}_${mm}${aa}) -width 14
 	    }
-	    for {set mm 20} {$mm<30} {incr mm} {
-		ttk::label $pv20.tpv${ii}_${mm}${aa} \
+	    for {set mm 24} {$mm<36} {incr mm} {
+		ttk::label $pv24.tpv${ii}_${mm}${aa} \
 		    -text "PV${ii}_${mm}${bb}"
-		ttk::entry $pv20.pv${ii}_${mm}${aa} \
-		    -textvariable dwcs(pv${ii}_${mm}${aa}) -width 14
-	    }
-	    for {set mm 30} {$mm<40} {incr mm} {
-		ttk::label $pv30.tpv${ii}_${mm}${aa} \
-		    -text "PV${ii}_${mm}${bb}"
-		ttk::entry $pv30.pv${ii}_${mm}${aa} \
-		    -textvariable dwcs(pv${ii}_${mm}${aa}) -width 14
-	    }
-	    for {set mm 40} {$mm<50} {incr mm} {
-		ttk::label $pv40.tpv${ii}_${mm}${aa} \
-		    -text "PV${ii}_${mm}${bb}"
-		ttk::entry $pv40.pv${ii}_${mm}${aa} \
+		ttk::entry $pv24.pv${ii}_${mm}${aa} \
 		    -textvariable dwcs(pv${ii}_${mm}${aa}) -width 14
 	    }
 	}
     }
 
+    # only in primary
+    ttk::label $ab0.ta -text "A_ORDER"
+    ttk::entry $ab0.a -textvariable dwcs(a_order) -width 14
+    for {set mm 0} {$mm<2} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    ttk::label $ab0.ta_${mm}_${nn} -text "A_${mm}_${nn}"
+	    ttk::entry $ab0.a_${mm}_${nn} \
+		-textvariable dwcs(a_${mm}_${nn}) -width 14
+	}
+    }
+    for {set mm 2} {$mm<4} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    ttk::label $ab2.ta_${mm}_${nn} -text "A_${mm}_${nn}"
+	    ttk::entry $ab2.a_${mm}_${nn} \
+		-textvariable dwcs(a_${mm}_${nn}) -width 14
+	}
+    }
+    for {set mm 4} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    ttk::label $ab4.ta_${mm}_${nn} -text "A_${mm}_${nn}"
+	    ttk::entry $ab4.a_${mm}_${nn} \
+		-textvariable dwcs(a_${mm}_${nn}) -width 14
+	}
+    }
+
+    ttk::label $ab0.tb -text "B_ORDER"
+    ttk::entry $ab0.b -textvariable dwcs(b_order) -width 14
+    for {set mm 0} {$mm<2} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    ttk::label $ab0.tb_${mm}_${nn} -text "B_${mm}_${nn}"
+	    ttk::entry $ab0.b_${mm}_${nn} \
+		-textvariable dwcs(b_${mm}_${nn}) -width 14
+	}
+    }
+    for {set mm 2} {$mm<4} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    ttk::label $ab2.tb_${mm}_${nn} -text "B_${mm}_${nn}"
+	    ttk::entry $ab2.b_${mm}_${nn} \
+		-textvariable dwcs(b_${mm}_${nn}) -width 14
+	}
+    }
+    for {set mm 4} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    ttk::label $ab4.tb_${mm}_${nn} -text "B_${mm}_${nn}"
+	    ttk::entry $ab4.b_${mm}_${nn} \
+		-textvariable dwcs(b_${mm}_${nn}) -width 14
+	}
+    }
+
+    ttk::label $apbp0.tap -text "AP_ORDER"
+    ttk::entry $apbp0.ap -textvariable dwcs(ap_order) -width 14
+    for {set mm 0} {$mm<2} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    ttk::label $apbp0.tap_${mm}_${nn} -text "AP_${mm}_${nn}"
+	    ttk::entry $apbp0.ap_${mm}_${nn} \
+		-textvariable dwcs(ap_${mm}_${nn}) -width 14
+	}
+    }
+    for {set mm 2} {$mm<4} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    ttk::label $apbp2.tap_${mm}_${nn} -text "AP_${mm}_${nn}"
+	    ttk::entry $apbp2.ap_${mm}_${nn} \
+		-textvariable dwcs(ap_${mm}_${nn}) -width 14
+	}
+    }
+    for {set mm 4} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    ttk::label $apbp4.tap_${mm}_${nn} -text "AP_${mm}_${nn}"
+	    ttk::entry $apbp4.ap_${mm}_${nn} \
+		-textvariable dwcs(ap_${mm}_${nn}) -width 14
+	}
+    }
+
+    ttk::label $apbp0.tbp -text "BP_ORDER"
+    ttk::entry $apbp0.bp -textvariable dwcs(bp_order) -width 14
+    for {set mm 0} {$mm<2} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    ttk::label $apbp0.tbp_${mm}_${nn} -text "BP_${mm}_${nn}"
+	    ttk::entry $apbp0.bp_${mm}_${nn} \
+		-textvariable dwcs(bp_${mm}_${nn}) -width 14
+	}
+    }
+    for {set mm 2} {$mm<4} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    ttk::label $apbp2.tbp_${mm}_${nn} -text "BP_${mm}_${nn}"
+	    ttk::entry $apbp2.bp_${mm}_${nn} \
+		-textvariable dwcs(bp_${mm}_${nn}) -width 14
+	}
+    }
+    for {set mm 4} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    ttk::label $apbp4.tbp_${mm}_${nn} -text "BP_${mm}_${nn}"
+	    ttk::entry $apbp4.bp_${mm}_${nn} \
+		-textvariable dwcs(bp_${mm}_${nn}) -width 14
+	}
+    }
+
     # Buttons
     set f [ttk::frame $w.buttons]
     ttk::button $f.apply -text [msgcat::mc {Apply}] -command WCSApplyDialog
@@ -401,15 +521,28 @@ proc ConfigWCSDialog {{force {0}}} {
     set tt $iwcs(top).param
     set base $tt.base
     set pv00 $tt.pv00
-    set pv10 $tt.pv10
-    set pv20 $tt.pv20
-    set pv30 $tt.pv30
-    set pv40 $tt.pv40
+    set pv12 $tt.pv12
+    set pv24 $tt.pv24
+    set ab0 $tt.ab0
+    set ab2 $tt.ab2
+    set ab4 $tt.ab4
+    set apbp0 $tt.apbp0
+    set apbp2 $tt.apbp2
+    set apbp4 $tt.apbp4
+
+    grid forget $base.tmjdobs $base.mjdobs
+    grid forget $base.tdateobs $base.dateobs
+    grid forget $base.tdate $base.date
+    grid forget $base.tepoch $base.epoch
 
     # forget current sys vars
     set aa [string tolower [string range $dwcs(prev) 3 3]]
 
     grid forget $base.twcsname${aa} $base.wcsname${aa}
+    grid forget $base.tradesys${aa} $base.radesys${aa}
+    grid forget $base.tequinox${aa} $base.equinox${aa}
+    grid forget $base.tlatpole${aa} $base.latpole${aa}
+    grid forget $base.tlonpole${aa} $base.lonpole${aa}
 
     for {set ii 1} {$ii<=2} {incr ii} {
 	grid forget $base.tctype${ii}${aa} $base.ctype${ii}${aa}
@@ -423,20 +556,83 @@ proc ConfigWCSDialog {{force {0}}} {
 	    grid forget $base.tpc${ii}_${jj}${aa} $base.pc${ii}_${jj}${aa}
 	}
 
-	for {set mm 0} {$mm<10} {incr mm} {
+	for {set mm 0} {$mm<12} {incr mm} {
 	    grid forget $pv00.tpv${ii}_${mm}${aa} $pv00.pv${ii}_${mm}${aa}
 	}
-	for {set mm 10} {$mm<20} {incr mm} {
-	    grid forget $pv10.tpv${ii}_${mm}${aa} $pv10.pv${ii}_${mm}${aa}
+	for {set mm 12} {$mm<24} {incr mm} {
+	    grid forget $pv12.tpv${ii}_${mm}${aa} $pv12.pv${ii}_${mm}${aa}
 	}
-	for {set mm 20} {$mm<30} {incr mm} {
-	    grid forget $pv20.tpv${ii}_${mm}${aa} $pv20.pv${ii}_${mm}${aa}
+	for {set mm 24} {$mm<36} {incr mm} {
+	    grid forget $pv24.tpv${ii}_${mm}${aa} $pv24.pv${ii}_${mm}${aa}
 	}
-	for {set mm 30} {$mm<40} {incr mm} {
-	    grid forget $pv30.tpv${ii}_${mm}${aa} $pv30.pv${ii}_${mm}${aa}
+    }
+
+    # only in primary
+    grid forget $ab0.ta $ab0.a
+    for {set mm 0} {$mm<2} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid forget $ab0.ta_${mm}_${nn} $ab0.a_${mm}_${nn}
 	}
-	for {set mm 40} {$mm<50} {incr mm} {
-	    grid forget $pv40.tpv${ii}_${mm}${aa} $pv40.pv${ii}_${mm}${aa}
+    }
+    for {set mm 2} {$mm<4} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid forget $ab2.ta_${mm}_${nn} $ab2.a_${mm}_${nn}
+	}
+    }
+    for {set mm 4} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid forget $ab4.ta_${mm}_${nn} $ab4.a_${mm}_${nn}
+	}
+    }
+
+    grid forget $ab0.tb $ab0.b
+    for {set mm 0} {$mm<2} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid forget $ab0.tb_${mm}_${nn} $ab0.b_${mm}_${nn}
+	}
+    }
+    for {set mm 2} {$mm<4} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid forget $ab2.tb_${mm}_${nn} $ab2.b_${mm}_${nn}
+	}
+    }
+    for {set mm 4} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid forget $ab4.tb_${mm}_${nn} $ab4.b_${mm}_${nn}
+	}
+    }
+
+    grid forget $apbp0.tap $apbp0.ap
+    for {set mm 0} {$mm<2} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid forget $apbp0.tap_${mm}_${nn} $apbp0.ap_${mm}_${nn}
+	}
+    }
+    for {set mm 2} {$mm<4} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid forget $apbp2.tap_${mm}_${nn} $apbp2.ap_${mm}_${nn}
+	}
+    }
+    for {set mm 4} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid forget $apbp4.tap_${mm}_${nn} $apbp4.ap_${mm}_${nn}
+	}
+    }
+
+    grid forget $apbp0.tbp $apbp0.bp
+    for {set mm 0} {$mm<2} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid forget $apbp0.tbp_${mm}_${nn} $apbp0.bp_${mm}_${nn}
+	}
+    }
+    for {set mm 2} {$mm<4} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid forget $apbp2.tbp_${mm}_${nn} $apbp2.bp_${mm}_${nn}
+	}
+    }
+    for {set mm 4} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid forget $apbp4.tbp_${mm}_${nn} $apbp4.bp_${mm}_${nn}
 	}
     }
 
@@ -445,6 +641,13 @@ proc ConfigWCSDialog {{force {0}}} {
     set aa [string tolower [string range $dwcs(system) 3 3]]
 
     grid $base.twcsname${aa} $base.wcsname${aa} -padx 2 -pady 2 -sticky w
+    grid $base.tradesys${aa} $base.radesys${aa} -padx 2 -pady 2 -sticky w
+
+    grid $base.tequinox${aa} $base.equinox${aa} \
+	$base.tepoch $base.epoch -padx 2 -pady 2 -sticky w
+    grid $base.tmjdobs $base.mjdobs -padx 2 -pady 2 -sticky w
+    grid $base.tdateobs $base.dateobs \
+	$base.tdate $base.date -padx 2 -pady 2 -sticky w
 
     grid $base.tctype1${aa} $base.ctype1${aa} \
 	$base.tctype2${aa} $base.ctype2${aa} -padx 2 -pady 2 -sticky w
@@ -467,30 +670,70 @@ proc ConfigWCSDialog {{force {0}}} {
     grid $base.tpc1_2${aa} $base.pc1_2${aa} \
 	$base.tpc2_2${aa} $base.pc2_2${aa} -padx 2 -pady 2 -sticky w
 
-    for {set mm 0} {$mm<10} {incr mm} {
+    grid $base.tlatpole${aa} $base.latpole${aa} \
+	$base.tlonpole${aa} $base.lonpole${aa} -padx 2 -pady 2 -sticky w
+
+    for {set mm 0} {$mm<12} {incr mm} {
 	grid $pv00.tpv1_${mm}${aa} $pv00.pv1_${mm}${aa} \
 	    $pv00.tpv2_${mm}${aa} $pv00.pv2_${mm}${aa} \
 	    -padx 2 -pady 2 -sticky w
     }
-    for {set mm 10} {$mm<20} {incr mm} {
-	grid $pv10.tpv1_${mm}${aa} $pv10.pv1_${mm}${aa} \
-	    $pv10.tpv2_${mm}${aa} $pv10.pv2_${mm}${aa} \
+    for {set mm 12} {$mm<24} {incr mm} {
+	grid $pv12.tpv1_${mm}${aa} $pv12.pv1_${mm}${aa} \
+	    $pv12.tpv2_${mm}${aa} $pv12.pv2_${mm}${aa} \
 	    -padx 2 -pady 2 -sticky w
     }
-    for {set mm 20} {$mm<30} {incr mm} {
-	grid $pv20.tpv1_${mm}${aa} $pv20.pv1_${mm}${aa} \
-	    $pv20.tpv2_${mm}${aa} $pv20.pv2_${mm}${aa} \
+    for {set mm 24} {$mm<36} {incr mm} {
+	grid $pv24.tpv1_${mm}${aa} $pv24.pv1_${mm}${aa} \
+	    $pv24.tpv2_${mm}${aa} $pv24.pv2_${mm}${aa} \
 	    -padx 2 -pady 2 -sticky w
     }
-    for {set mm 30} {$mm<40} {incr mm} {
-	grid $pv30.tpv1_${mm}${aa} $pv30.pv1_${mm}${aa} \
-	    $pv30.tpv2_${mm}${aa} $pv30.pv2_${mm}${aa} \
-	    -padx 2 -pady 2 -sticky w
+
+    # only in primary
+    grid $ab0.ta $ab0.a $ab0.tb $ab0.b -padx 2 -pady 2 -sticky w
+    for {set mm 0} {$mm<2} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid $ab0.ta_${mm}_${nn} $ab0.a_${mm}_${nn} \
+		$ab0.tb_${mm}_${nn} $ab0.b_${mm}_${nn} \
+		-padx 2 -pady 2 -sticky w
+	}
     }
-    for {set mm 40} {$mm<50} {incr mm} {
-	grid $pv40.tpv1_${mm}${aa} $pv40.pv1_${mm}${aa} \
-	    $pv40.tpv2_${mm}${aa} $pv40.pv2_${mm}${aa} \
-	    -padx 2 -pady 2 -sticky w
+    for {set mm 2} {$mm<4} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid $ab2.ta_${mm}_${nn} $ab2.a_${mm}_${nn} \
+		$ab2.tb_${mm}_${nn} $ab2.b_${mm}_${nn} \
+		-padx 2 -pady 2 -sticky w
+	}
+    }
+    for {set mm 4} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid $ab4.ta_${mm}_${nn} $ab4.a_${mm}_${nn} \
+		$ab4.tb_${mm}_${nn} $ab4.b_${mm}_${nn} \
+		-padx 2 -pady 2 -sticky w
+	}
+    }
+
+    grid $apbp0.tap $apbp0.ap $apbp0.tbp $apbp0.bp -padx 2 -pady 2 -sticky w
+    for {set mm 0} {$mm<2} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid $apbp0.tap_${mm}_${nn} $apbp0.ap_${mm}_${nn} \
+		$apbp0.tbp_${mm}_${nn} $apbp0.bp_${mm}_${nn} \
+		-padx 2 -pady 2 -sticky w
+	}
+    }
+    for {set mm 2} {$mm<4} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid $apbp2.tap_${mm}_${nn} $apbp2.ap_${mm}_${nn} \
+		$apbp2.tbp_${mm}_${nn} $apbp2.bp_${mm}_${nn} \
+		-padx 2 -pady 2 -sticky w
+	}
+    }
+    for {set mm 4} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    grid $apbp4.tap_${mm}_${nn} $apbp4.ap_${mm}_${nn} \
+		$apbp4.tbp_${mm}_${nn} $apbp4.bp_${mm}_${nn} \
+		-padx 2 -pady 2 -sticky w
+	}
     }
 }
 
@@ -536,8 +779,17 @@ proc WCSToVar {txt} {
     global iwcs
 
     # clear all
+    set dwcs(mjd-obs) {}
+    set dwcs(date-obs) {}
+    set dwcs(date) {}
+    set dwcs(epoch) {}
+
     foreach aa {{} a b c d e f g h i j k l m n o p q r s t u v w x y z} {
 	set dwcs(wcsname${aa}) {}
+	set dwcs(radesys${aa}) {}
+	set dwcs(equinox${aa}) {}
+	set dwcs(latpole${aa}) {}
+	set dwcs(lonpole${aa}) {}
 
 	for {set ii 1} {$ii<=2} {incr ii} {
 	    set dwcs(ctype${ii}${aa}) {}
@@ -551,11 +803,37 @@ proc WCSToVar {txt} {
 		set dwcs(pc${ii}_${jj}${aa}) {}
 	    }
 
-	    for {set mm 0} {$mm<50} {incr mm} {
+	    for {set mm 0} {$mm<36} {incr mm} {
 		set dwcs(pv${ii}_${mm}${aa}) {}
 	    }
 	}
     }
+    
+    # primary only
+    set dwcs(a_order) {}
+    for {set mm 0} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    set dwcs(a_${mm}_${nn}) {}
+	}
+    }
+    set dwcs(b_order) {}
+    for {set mm 0} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    set dwcs(b_${mm}_${nn}) {}
+	}
+    }
+    set dwcs(ap_order) {}
+    for {set mm 0} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    set dwcs(ap_${mm}_${nn}) {}
+	}
+    }
+    set dwcs(bp_order) {}
+    for {set mm 0} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    set dwcs(bp_${mm}_${nn}) {}
+	}
+    }
 
     set lines [split $txt "\n"]
 
@@ -574,7 +852,24 @@ proc WCSToVar {txt} {
 	set key [string tolower [string trim [lindex $pp 0]]]
 
 	# drop comments
-	set aa [lindex [split [lindex $pp 1] {/}] 0]
+	#   some keywords can have '/' in the value (such as a date)
+	#   try the easy approach first
+	set ee [lindex $pp 1]
+	set dd [split $ee {/}]
+	switch [llength $dd] {
+	    0 -
+	    1 -
+	    2 {set aa [lindex $dd 0]}
+	    default {
+		set ff [string first { /} $ee]
+		if {$ff > 0} {
+		    set aa [string range $ee 0 $ff]
+		} else {
+		    set aa [lindex $dd 0]
+		}
+	    }
+	}
+
 	# drop any white space
 	set bb [string trim $aa]
 	# drop any single quotes
@@ -583,8 +878,25 @@ proc WCSToVar {txt} {
 	set val [string trim $cc]
 
 	# sanity check
+	if {$key == {longpole}} {
+	    set key lonpole
+	}
+	if {$key == {radecsys}} {
+	    set key radesys
+	}
+
+	switch [string range $key 0 6] {
+	    mjd-obs -
+	    date-ob {
+		set dwcs($key) $val
+	    }
+	}
 	switch [string range $key 0 5] {
 	    wcsnam -
+	    radesy -
+	    equino -
+	    latpol -
+	    lonpol -
 	    ctype1 -
 	    ctype2 -
 	    cunit1 -
@@ -594,11 +906,17 @@ proc WCSToVar {txt} {
 	    crval1 -
 	    crval2 -
 	    cdelt1 -
-	    cdelt2 {
+	    cdelt2 -
+	    a_orde -
+	    b_orde -
+	    ap_ord -
+	    bp_ord {
 		set dwcs($key) $val
 	    }
 	}
 	switch [string range $key 0 3] {
+	    epoc -
+	    date -
 	    cd1_ -
 	    cd1_ -
 	    cd2_ -
@@ -612,6 +930,18 @@ proc WCSToVar {txt} {
 		set dwcs($key) $val
 	    }
 	}
+	switch [string range $key 0 2] {
+	    ap_ -
+	    bp_ {
+		set dwcs($key) $val
+	    }
+	}
+	switch [string range $key 0 1] {
+	    a_ -
+	    b_ {
+		set dwcs($key) $val
+	    }
+	}
     }
 }
 
@@ -623,12 +953,37 @@ proc WCSFromVar {} {
 
     set rr {}
 
+    if {$dwcs(mjd-obs) != {}} {
+	append rr "MJD-OBS = $dwcs(mjd-obs)\n"
+    }
+    if {$dwcs(date-obs) != {}} {
+	append rr "DATE-OBS = '$dwcs(date-obs)'\n"
+    }
+    if {$dwcs(date) != {}} {
+	append rr "DATE = '$dwcs(date)'\n"
+    }
+    if {$dwcs(epoch) != {}} {
+	append rr "EPOCH = $dwcs(epoch)\n"
+    }
+
     foreach aa {{} a b c d e f g h i j k l m n o p q r s t u v w x y z} {
 	set bb [string toupper $aa]
 
 	if {$dwcs(wcsname${aa}) != {}} {
 	    append rr "WCSNAME${bb} = '$dwcs(wcsname${aa})'\n"
 	}
+	if {$dwcs(radesys${aa}) != {}} {
+	    append rr "RADESYS${bb} = '$dwcs(radesys${aa})'\n"
+	}
+	if {$dwcs(equinox${aa}) != {}} {
+	    append rr "EQUINOX${bb} = $dwcs(equinox${aa})\n"
+	}
+	if {$dwcs(latpole${aa}) != {}} {
+	    append rr "LATPOLE${bb} = $dwcs(latpole${aa})\n"
+	}
+	if {$dwcs(lonpole${aa}) != {}} {
+	    append rr "LONPOLE${bb} = $dwcs(lonpole${aa})\n"
+	}
 
 	for {set ii 1} {$ii<=2} {incr ii} {
 	    if {$dwcs(ctype${ii}${aa}) != {}} {
@@ -656,7 +1011,7 @@ proc WCSFromVar {} {
 		}
 	    }
 
-	    for {set mm 0} {$mm<50} {incr mm} {
+	    for {set mm 0} {$mm<36} {incr mm} {
 		if {$dwcs(pv${ii}_${mm}${aa}) != {}} {
 		    append rr "PV${ii}_${mm}${bb} = $dwcs(pv${ii}_${mm}${aa})\n"
 		}
@@ -664,7 +1019,49 @@ proc WCSFromVar {} {
 	}
     }
 
-    return $rr 
+    if {$dwcs(a_order) != {}} {
+	append rr "A_ORDER = $dwcs(a_order)\n"
+    }
+    for {set mm 0} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    if {$dwcs(a_${mm}_${nn}) != {}} {
+		append rr "A_${mm}_${nn} = $dwcs(a_${mm}_${nn})\n"
+	    }
+	}
+    }
+    if {$dwcs(b_order) != {}} {
+	append rr "B_ORDER = $dwcs(b_order)\n"
+    }
+    for {set mm 0} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    if {$dwcs(b_${mm}_${nn}) != {}} {
+		append rr "B_${mm}_${nn} = $dwcs(b_${mm}_${nn})\n"
+	    }
+	}
+    }
+
+    if {$dwcs(ap_order) != {}} {
+	append rr "AP_ORDER = $dwcs(ap_order)\n"
+    }
+    for {set mm 0} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    if {$dwcs(ap_${mm}_${nn}) != {}} {
+		append rr "AP_${mm}_${nn} = $dwcs(ap_${mm}_${nn})\n"
+	    }
+	}
+    }
+    if {$dwcs(bp_order) != {}} {
+	append rr "BP_ORDER = $dwcs(bp_order)\n"
+    }
+    for {set mm 0} {$mm<6} {incr mm} {
+	for {set nn 0} {$nn<6} {incr nn} {
+	    if {$dwcs(bp_${mm}_${nn}) != {}} {
+		append rr "BP_${mm}_${nn} = $dwcs(bp_${mm}_${nn})\n"
+	    }
+	}
+    }
+
+    return $rr
 }
 
 # Process Cmds
