@@ -26,7 +26,7 @@ doit () {
 #	  -private
 #	  -visual
 
-if [ "$1" = "2mass" -o -z "$1" ]; then
+if [ "$1" = "2mass" ]; then
 initit "2mass"
 testit "-2mass open"
 testit "-2mass close"
@@ -55,7 +55,12 @@ testit "-3d"
 testit "-3d vp 45 30"
 testit "-3d az 45"
 testit "-3d el 30"
+testit "-3d scale 5"
 testit "-3d method mip"
+testit "-3d border yes"
+testit "-3d border color red"
+testit "-3d compass yes"
+testit "-3d compass color red"
 testit "-3d highlite yes"
 testit "-3d highlite color red"
 testit "-3d close"
@@ -146,12 +151,13 @@ testit "-catalog cds 'I/284'"
 testit "-catalog clear"
 testit "-catalog close"
 
-testit "-catalog load sb ds9.cat"
+testit "-catalog import sb ds9.cat"
 testit "-catalog clear"
 testit "-catalog close"
 
 testit "-catalog cds 2mass"
 testit "-raise"
+testit "-catalog plot '\$Jmag' '\$Hmag' '\$e_Jmag' '\$e_Hmag'"
 testit "-catalog symbol condition '\$Jmag>15'"
 testit "-catalog symbol shape 'boxcircle point'"
 testit "-catalog symbol color red"
@@ -192,6 +198,21 @@ testit "-catalog hide"
 testit "-catalog show"
 testit "-catalog panto no"
 #testit "-catalog edit yes"
+testit "-catalog location 400"
+testit "-catalog header"
+testit "-catalog clear"
+testit "-catalog close"
+testit "-catalog 2mass"
+testit "-catalog xmm"
+testit "-catalog match function 1and2"
+testit "-catalog match error 2 arcsec"
+testit "-catalog match return 1only"
+testit "-catalog match unique no"
+testit "-catalog match 2mass xmm"
+testit "-catalog clear"
+testit "-catalog close"
+testit "-catalog clear"
+testit "-catalog close"
 testit "-catalog clear"
 testit "-catalog close"
 doit
@@ -346,7 +367,7 @@ testit "-file hst.fits"
 testit "-single"
 testit "-cube 2"
 testit "-cube interval .5"
-testit "-cube axis 2"
+testit "-cube axis 3"
 testit "-cube play"
 testit "-cube stop"
 testit "-cube match"
@@ -666,8 +687,10 @@ testit "-lock bin yes"
 testit "-lock bin no"
 testit "-lock scale yes"
 testit "-lock scale no"
-testit "-lock color yes"
-testit "-lock color no"
+testit "-lock colorbar yes"
+testit "-lock colorbar no"
+testit "-lock smooth yes"
+testit "-lock smooth no"
 testit "-mode pointer"
 testit "-frame delete"
 testit "-wcs align no"
@@ -716,7 +739,8 @@ testit "-match crop wcs"
 testit "-match slice"
 testit "-match bin"
 testit "-match scale"
-testit "-match color"
+testit "-match colorbar"
+testit "-match smooth"
 testit "-frame delete"
 testit "-mode pointer"
 testit "-single"
@@ -775,7 +799,8 @@ fi
 
 if [ "$1" = "movie" -o -z "$1" ]; then
 initit "movie"
-testit "-width 700 -height 400"
+testit "-width 715 -height 450"
+testit "-movie slice foo.mpg"
 testit "-movie frame foo.mpg"
 testit "-frame new 3d"
 testit "-movie 3d foo.mpg number 1 azfrom 0 azto 0 elfrom 0 elto 0 slfrom 1 slto 1 repeat 1"
@@ -903,6 +928,25 @@ testit "-plot close"
 testit "-plot close"
 testit "-plot close"
 
+testit "-plot bar"
+testit "-plot new bar"
+testit "-plot new name foo bar"
+testit "-plot new name foo bar 'The Title' 'X Axis' 'Y Axis' xy"
+testit "-plot close"
+testit "-plot close"
+testit "-plot close"
+testit "-plot close"
+doit
+exit
+testit "-plot scatter"
+testit "-plot new scatter"
+testit "-plot new name foo scatter"
+testit "-plot new name foo scatter 'The Title' 'X Axis' 'Y Axis' xy"
+testit "-plot close"
+testit "-plot close"
+testit "-plot close"
+testit "-plot close"
+
 echo "..4|5"
 testit "-plot new 'The Title' 'X Axis' 'Y Axis' 4"
 testit "-plot load 4.dat 4"
@@ -911,6 +955,20 @@ testit "-plot load 5.dat 5"
 testit "-plot close"
 testit "-plot close"
 
+testit "-plot new bar 'The Title' 'X Axis' 'Y Axis' 4"
+testit "-plot load 4.dat 4"
+testit "-plot new bar 'The Title' 'X Axis' 'Y Axis' 5"
+testit "-plot load 5.dat 5"
+testit "-plot close"
+testit "-plot close"
+
+testit "-plot new scatter 'The Title' 'X Axis' 'Y Axis' 4"
+testit "-plot load 4.dat 4"
+testit "-plot new scatter 'The Title' 'X Axis' 'Y Axis' 5"
+testit "-plot load 5.dat 5"
+testit "-plot close"
+testit "-plot close"
+
 echo "..named 4|5"
 testit "-plot new name foo 'The Title' 'X Axis' 'Y Axis' 4"
 testit "-plot load 4.dat 4"
@@ -919,6 +977,20 @@ testit "-plot load 5.dat 5"
 testit "-plot close"
 testit "-plot close"
 
+testit "-plot new name foo bar 'The Title' 'X Axis' 'Y Axis' 4"
+testit "-plot load 4.dat 4"
+testit "-plot new name foo bar 'The Title' 'X Axis' 'Y Axis' 5"
+testit "-plot load 5.dat 5"
+testit "-plot close"
+testit "-plot close"
+
+testit "-plot new name foo scatter 'The Title' 'X Axis' 'Y Axis' 4"
+testit "-plot load 4.dat 4"
+testit "-plot new name foo scatter 'The Title' 'X Axis' 'Y Axis' 5"
+testit "-plot load 5.dat 5"
+testit "-plot close"
+testit "-plot close"
+
 echo "..xy|xyex|xyey|xyexey"
 testit "-plot new 'The Title' 'X Axis' 'Y Axis' xy"
 testit "-plot load xy.dat xy"
@@ -928,7 +1000,32 @@ testit "-plot new 'The Title' 'X Axis' 'Y Axis' xyey"
 testit "-plot load xyey.dat xyey"
 testit "-plot new 'The Title' 'X Axis' 'Y Axis' xyexey"
 testit "-plot load xyexey.dat xyexey"
-sleep "$delay"
+testit "-plot close"
+testit "-plot close"
+testit "-plot close"
+testit "-plot close"
+
+testit "-plot new bar 'The Title' 'X Axis' 'Y Axis' xy"
+testit "-plot load xy.dat xy"
+testit "-plot new bar 'The Title' 'X Axis' 'Y Axis' xyex"
+testit "-plot load xyex.dat xyex"
+testit "-plot new bar 'The Title' 'X Axis' 'Y Axis' xyey"
+testit "-plot load xyey.dat xyey"
+testit "-plot new bar 'The Title' 'X Axis' 'Y Axis' xyexey"
+testit "-plot load xyexey.dat xyexey"
+testit "-plot close"
+testit "-plot close"
+testit "-plot close"
+testit "-plot close"
+
+testit "-plot new scatter 'The Title' 'X Axis' 'Y Axis' xy"
+testit "-plot load xy.dat xy"
+testit "-plot new scatter 'The Title' 'X Axis' 'Y Axis' xyex"
+testit "-plot load xyex.dat xyex"
+testit "-plot new scatter 'The Title' 'X Axis' 'Y Axis' xyey"
+testit "-plot load xyey.dat xyey"
+testit "-plot new scatter 'The Title' 'X Axis' 'Y Axis' xyexey"
+testit "-plot load xyexey.dat xyexey"
 testit "-plot close"
 testit "-plot close"
 testit "-plot close"
@@ -943,7 +1040,32 @@ testit "-plot new name foo 'The Title' 'X Axis' 'Y Axis' xyey"
 testit "-plot load xyey.dat xyey"
 testit "-plot new name foo 'The Title' 'X Axis' 'Y Axis' xyexey"
 testit "-plot load xyexey.dat xyexey"
-sleep "$delay"
+testit "-plot close"
+testit "-plot close"
+testit "-plot close"
+testit "-plot close"
+
+testit "-plot new name foo bar 'The Title' 'X Axis' 'Y Axis' xy"
+testit "-plot load xy.dat xy"
+testit "-plot new name foo bar 'The Title' 'X Axis' 'Y Axis' xyex"
+testit "-plot load xyex.dat xyex"
+testit "-plot new name foo bar 'The Title' 'X Axis' 'Y Axis' xyey"
+testit "-plot load xyey.dat xyey"
+testit "-plot new name foo bar 'The Title' 'X Axis' 'Y Axis' xyexey"
+testit "-plot load xyexey.dat xyexey"
+testit "-plot close"
+testit "-plot close"
+testit "-plot close"
+testit "-plot close"
+
+testit "-plot new name foo scatter 'The Title' 'X Axis' 'Y Axis' xy"
+testit "-plot load xy.dat xy"
+testit "-plot new name foo scatter 'The Title' 'X Axis' 'Y Axis' xyex"
+testit "-plot load xyex.dat xyex"
+testit "-plot new name foo scatter 'The Title' 'X Axis' 'Y Axis' xyey"
+testit "-plot load xyey.dat xyey"
+testit "-plot new name foo scatter 'The Title' 'X Axis' 'Y Axis' xyexey"
+testit "-plot load xyexey.dat xyexey"
 testit "-plot close"
 testit "-plot close"
 testit "-plot close"
@@ -978,14 +1100,21 @@ rm -f foo.ps
 
 echo "..grid"
 testit "-plot new"
-testit "-plot graph grid yes"
-testit "-plot graph scale loglog"
-testit "-plot graph range x auto no"
+testit "-plot load xy.dat xy"
+testit "-plot graph grid x no"
+testit "-plot graph grid y yes"
+testit "-plot graph log x no"
+testit "-plot graph log y no"
+testit "-plot graph flip x no"
+testit "-plot graph flip y no"
 testit "-plot graph range x min 1"
 testit "-plot graph range x max 100"
-testit "-plot graph range y auto no"
 testit "-plot graph range y min 1"
 testit "-plot graph range y max 100"
+testit "-plot graph range x auto no"
+testit "-plot graph range y auto no"
+testit "-plot graph format x {}"
+testit "-plot graph format y {}"
 testit "-plot graph labels title 'The Title'"
 testit "-plot graph labels xaxis 'X Axis'"
 testit "-plot graph labels yaxis 'Y Axis'"
@@ -1044,7 +1173,7 @@ testit "-inet_only"
 doit
 fi
 
-if [ "$1" = "prefs" -o -z "$1" ]; then
+if [ "$1" = "prefs" ]; then
 initit "prefs"
 testit "-prefs clear"
 doit
@@ -1364,6 +1493,9 @@ testit "-smooth"
 testit "-smooth yes"
 testit "-smooth function tophat"
 testit "-smooth radius 5"
+testit "-smooth match"
+testit "-smooth lock yes"
+testit "-smooth lock no"
 testit "-smooth no"
 testit "-smooth close"
 doit
@@ -1521,8 +1653,8 @@ fi
 
 if [ "$1" = "web" -o -z "$1" ]; then
 initit "web"
-testit "-web hea-www.harvard.edu/RD/ds9/"
-testit "-web hea-www.harvard.edu/RD/ds9/beta.html"
+testit "-web hea-www.harvard.edu/RD/ds9/acknowledgment.html"
+testit "-web hea-www.harvard.edu/RD/ds9/helpdesk.html"
 testit "-web hvweb click back"
 testit "-web click forward"
 testit "-web clear"
