@@ -33,51 +33,52 @@ testit () {
 xpaset -p ds9 grid yes
 xpaset -p ds9 wcs skyformat deg
 
-echo "GLON--RA"
+echo "STScI DSS"
+testit wcen.fits.gz
+
+echo "Old SCAMP"
+testit ngc6819.fits
+
+echo "TAN+ PV"
+testit paucam_0_0_t7_0_science.fits
+
+echo "TAN PV2_1=0 PV2_2=0"
+testit a68.fits
+
+echo "ZPN+ PV"
+testit UKIDDS_K_3219_606_17_67_3.fits
+
+echo "TNX"
+testit 30s_01.fits
+
+echo "ZPX"
+testit E5.3090.fits
+
+echo "TAN-SIP"
+testit sst.fits
+testit mos8.fits
+
+echo "SAO Plate"
+testit ac.fits
+
+echo "WCSDEP"
+testit ngc6819.fits
+
+echo "HPX"
+testit wmap.fits
+
+echo "GLON-ZEA"
+testit South_galactic.fits
+
+echo "RA-CAR"
 testit CAR_model.fits
 testit car_01.fits
 
 echo "GLON-CAR"
 testit GLM_00350+0115_mosaic_I4_cutout_14706.fits
-testit GLM_03350+0000_mosaic_I1_cutout_10617.fits
-testit GP_343.5_+0.0_A.fits
-testit fermi_counts_gps_bin_1.00.fits
-testit gc_energybin07_fadapt10_smajor030.fits
-testit gc_energybin07_fadapt10_smajor100.fits
-testit msxmapA-1a.fits
-testit msxmapA-2.fits
-
-echo "GLON-ZEA"
-testit SFD_dust_4096_sgp.fits
-testit South_galactic.fits
-testit g000p00r2.fits
-
-echo "TNX---RA"
-testit 30s_01.fits
-testit cal000277b.fits
-testit mscred.fits
-testit obj094.fits
-testit obj269z.fits
-testit westphal_Rs.wcs.fits
-
-echo "ZPN---RA"
-testit ABELL0586.0750.fits
-testit D4.0705.fits
-testit EGS1.1193.fits
-testit LSSTtest.2124.fits
-testit UKIDDS_K_3219_606_17_67_3.fits
-testit rcs2_m3.2540.fits
-
-echo "ZPX---RA"
-testit E5.3090.fits
-testit E5.3075.fits
-
-echo "TAN---RA-SIP"
-testit sst.fits
 
 echo "IRAF"
 testit obj011.fits
-testit oct12_096.4.fits
 
 xpaset -p ds9 quit
 
