@@ -38,6 +38,9 @@ testit () {
     xpaset -p ds9 raise
 }
 
+# must be invoked
+#         imexam
+
 # load default image
 rm -f *.out
 xpaset -p ds9 scale zscale
@@ -45,7 +48,7 @@ xpaset -p ds9 file img16.fits
 
 delay=.5
 
-if [ "$1" = "2mass" -o -z "$1" ]; then
+if [ "$1" = "2mass" ]; then
 tt="2mass"
 xpaset -p ds9 2mass open
 xpaset -p ds9 2mass close
@@ -88,13 +91,23 @@ xpaset -p ds9 3d vp 45 30
 xpaget ds9 3d vp >> ${tt}.out
 xpaget ds9 3d az >> ${tt}.out
 xpaget ds9 3d el >> ${tt}.out
+xpaget ds9 3d scale >> ${tt}.out
 xpaget ds9 3d method >> ${tt}.out
+xpaget ds9 3d border >> ${tt}.out
+xpaget ds9 3d border color >> ${tt}.out
+xpaget ds9 3d compass >> ${tt}.out
+xpaget ds9 3d compass color >> ${tt}.out
 xpaget ds9 3d highlite >> ${tt}.out
 xpaget ds9 3d highlite color >> ${tt}.out
 xpaset -p ds9 3d vp 45 30
 xpaset -p ds9 3d az 45
 xpaset -p ds9 3d el 30
+xpaset -p ds9 3d scale 5
 xpaset -p ds9 3d method mip
+xpaset -p ds9 3d border yes
+xpaset -p ds9 3d border color red
+xpaset -p ds9 3d compass yes
+xpaset -p ds9 3d compass color red
 xpaset -p ds9 3d highlite yes
 xpaset -p ds9 3d highlite color red
 xpaset -p ds9 3d close
@@ -224,13 +237,14 @@ xpaset -p ds9 catalog cds "I/284"
 xpaset -p ds9 catalog clear
 xpaset -p ds9 catalog close
 
-xpaset -p ds9 catalog load sb ds9.cat
+xpaset -p ds9 catalog import sb ds9.cat
 xpaset -p ds9 catalog clear
 xpaset -p ds9 catalog close
 
 xpaset -p ds9 catalog cds 2mass
 xpaset -p ds9 raise
-xpaset -p ds9 catalog symbol condition "\$Jmag>15"
+xpaset -p ds9 catalog plot '$Jmag' '$Hmag' '$e_Jmag' '$e_Hmag'
+xpaset -p ds9 catalog symbol condition '$Jmag>15'
 xpaset -p ds9 catalog symbol shape "{boxcircle point}"
 xpaset -p ds9 catalog symbol color red
 xpaset -p ds9 catalog symbol condition "{}"
@@ -252,7 +266,7 @@ xpaset -p ds9 catalog skyformat degrees
 xpaset -p ds9 catalog size 22 22 arcmin
 xpaset -p ds9 catalog retrieve
 xpaset -p ds9 catalog save foo.cat
-xpaset -p ds9 catalog filter "\$Jmag>15"
+xpaset -p ds9 catalog filter '$Jmag>15'
 xpaset -p ds9 catalog filter load ds9.flt
 xpaset -p ds9 catalog retrieve
 xpaset -p ds9 catalog cancel
@@ -270,6 +284,21 @@ xpaset -p ds9 catalog hide
 xpaset -p ds9 catalog show
 xpaset -p ds9 catalog panto no
 #xpaset -p ds9 catalog edit yes
+xpaset -p ds9 catalog location 400
+xpaset -p ds9 catalog header
+xpaset -p ds9 catalog clear
+xpaset -p ds9 catalog close
+xpaset -p ds9 catalog 2mass
+xpaset -p ds9 catalog xmm
+xpaset -p ds9 catalog match function 1and2
+xpaset -p ds9 catalog match error 2 arcsec
+xpaset -p ds9 catalog match return 1only
+xpaset -p ds9 catalog match unique no
+xpaset -p ds9 catalog match 2mass xmm
+xpaset -p ds9 catalog clear
+xpaset -p ds9 catalog close
+xpaset -p ds9 catalog clear
+xpaset -p ds9 catalog close
 xpaset -p ds9 catalog clear
 xpaset -p ds9 catalog close
 rm -f foo.cat
@@ -456,7 +485,7 @@ xpaget ds9 cube axis >> ${tt}.out
 xpaget ds9 cube lock >> ${tt}.out
 xpaset -p ds9 cube 2
 xpaset -p ds9 cube interval .5
-xpaset -p ds9 cube axis 2
+xpaset -p ds9 cube axis 3
 xpaset -p ds9 cube play
 xpaset -p ds9 cube stop
 xpaset -p ds9 cube match
@@ -626,7 +655,7 @@ xpaset -p ds9 single
 testit $tt
 fi
 
-if [ "$1" = "first" -o -z "$1" ]; then
+if [ "$1" = "first" ]; then
 tt="first"
 xpaset -p ds9 first open
 xpaset -p ds9 first close
@@ -1000,7 +1029,8 @@ xpaget ds9 lock crop >> ${tt}.out
 xpaget ds9 lock slice >> ${tt}.out
 xpaget ds9 lock bin >> ${tt}.out
 xpaget ds9 lock scale >> ${tt}.out
-xpaget ds9 lock color >> ${tt}.out
+xpaget ds9 lock colorbar >> ${tt}.out
+xpaget ds9 lock smooth >> ${tt}.out
 xpaset -p ds9 file new img16.fits
 xpaset -p ds9 tile
 xpaset -p ds9 mode crosshair
@@ -1017,8 +1047,10 @@ xpaset -p ds9 lock bin yes
 xpaset -p ds9 lock bin no
 xpaset -p ds9 lock scale yes
 xpaset -p ds9 lock scale no
-xpaset -p ds9 lock color yes
-xpaset -p ds9 lock color no
+xpaset -p ds9 lock colorbar yes
+xpaset -p ds9 lock colorbar no
+xpaset -p ds9 lock smooth yes
+xpaset -p ds9 lock smooth no
 xpaset -p ds9 mode pointer
 xpaset -p ds9 frame delete
 xpaset -p ds9 wcs align no
@@ -1078,7 +1110,8 @@ xpaset -p ds9 match crop wcs
 xpaset -p ds9 match slice
 xpaset -p ds9 match bin
 xpaset -p ds9 match scale
-xpaset -p ds9 match color
+xpaset -p ds9 match colorbar
+xpaset -p ds9 match smooth
 xpaset -p ds9 frame delete
 xpaset -p ds9 mode pointer
 xpaset -p ds9 single
@@ -1111,10 +1144,11 @@ xpaset -p ds9 mode pointer
 testit $tt
 fi
 
+# movie will fail if moved from corner
 if [ "$1" = "movie" -o -z "$1" ]; then
 tt="movie"
-xpaset -p ds9 width 700
-xpaset -p ds9 height 400
+xpaset -p ds9 width 715
+xpaset -p ds9 height 450
 xpaset -p ds9 movie slice foo.mpg
 xpaset -p ds9 movie frame foo.mpg
 xpaset -p ds9 frame new 3d
@@ -1241,12 +1275,29 @@ tt="plot"
 echo "..empty plot"
 xpaset -p ds9 plot
 xpaget ds9 plot >> ${tt}.out
-
-xpaset -p ds9 plot new
-xpaset -p ds9 plot new name foo
-xpaset -p ds9 plot new name foo "{The Title}" "{X Axis}" "{Y Axis}" xy
 sleep "$delay"
 xpaset -p ds9 plot close
+
+xpaset -p ds9 plot new
+xpaset -p ds9 plot new bar
+xpaset -p ds9 plot new scatter
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
+xpaset -p ds9 plot new name foo
+xpaset -p ds9 plot new name foo bar
+xpaset -p ds9 plot new name foo scatter
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
+xpaset -p ds9 plot new name foo "{The Title}" "{X Axis}" "{Y Axis}" xy
+xpaset -p ds9 plot new name foo bar "{The Title}" "{X Axis}" "{Y Axis}" xy
+xpaset -p ds9 plot new name foo scatter "{The Title}" "{X Axis}" "{Y Axis}" xy
+sleep "$delay"
 xpaset -p ds9 plot close
 xpaset -p ds9 plot close
 xpaset -p ds9 plot close
@@ -1262,6 +1313,26 @@ xpaset -p ds9 plot close
 xpaset -p ds9 plot close
 xpaset -p ds9 plot close
 
+cat stdin.2.dat | xpaset ds9 plot new bar stdin
+cat stdin.3.dat | xpaset ds9 plot new bar stdin
+cat stdin.4.dat | xpaset ds9 plot new bar stdin
+cat stdin.5.dat | xpaset ds9 plot new bar stdin
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
+cat stdin.2.dat | xpaset ds9 plot new scatter stdin
+cat stdin.3.dat | xpaset ds9 plot new scatter stdin
+cat stdin.4.dat | xpaset ds9 plot new scatter stdin
+cat stdin.5.dat | xpaset ds9 plot new scatter stdin
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
 echo "..named stdin 2|3|4|5"
 cat stdin.2.dat | xpaset ds9 plot new name foo stdin
 cat stdin.3.dat | xpaset ds9 plot new name foo stdin
@@ -1273,6 +1344,26 @@ xpaset -p ds9 plot close
 xpaset -p ds9 plot close
 xpaset -p ds9 plot close
 
+cat stdin.2.dat | xpaset ds9 plot new name foo bar stdin
+cat stdin.3.dat | xpaset ds9 plot new name foo bar stdin
+cat stdin.4.dat | xpaset ds9 plot new name foo bar stdin
+cat stdin.5.dat | xpaset ds9 plot new name foo bar stdin
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
+cat stdin.2.dat | xpaset ds9 plot new name foo scatter stdin
+cat stdin.3.dat | xpaset ds9 plot new name foo scatter stdin
+cat stdin.4.dat | xpaset ds9 plot new name foo scatter stdin
+cat stdin.5.dat | xpaset ds9 plot new name foo scatter stdin
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
 echo "..stdin xy|xyex|xyey|xyexey"
 cat stdin.xy.dat | xpaset ds9 plot new stdin
 cat stdin.xyex.dat | xpaset ds9 plot new stdin
@@ -1284,6 +1375,26 @@ xpaset -p ds9 plot close
 xpaset -p ds9 plot close
 xpaset -p ds9 plot close
 
+cat stdin.xy.dat | xpaset ds9 plot new bar stdin
+cat stdin.xyex.dat | xpaset ds9 plot new bar stdin
+cat stdin.xyey.dat | xpaset ds9 plot new bar stdin
+cat stdin.xyexey.dat | xpaset ds9 plot new bar stdin
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
+cat stdin.xy.dat | xpaset ds9 plot new scatter stdin
+cat stdin.xyex.dat | xpaset ds9 plot new scatter stdin
+cat stdin.xyey.dat | xpaset ds9 plot new scatter stdin
+cat stdin.xyexey.dat | xpaset ds9 plot new scatter stdin
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
 echo "..named stdin xy|xyex|xyey|xyexey"
 cat stdin.xy.dat | xpaset ds9 plot new name foo stdin
 cat stdin.xyex.dat | xpaset ds9 plot new name foo stdin
@@ -1295,6 +1406,26 @@ xpaset -p ds9 plot close
 xpaset -p ds9 plot close
 xpaset -p ds9 plot close
 
+cat stdin.xy.dat | xpaset ds9 plot new name foo bar stdin
+cat stdin.xyex.dat | xpaset ds9 plot new name foo bar stdin
+cat stdin.xyey.dat | xpaset ds9 plot new name foo bar stdin
+cat stdin.xyexey.dat | xpaset ds9 plot new name foo bar stdin
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
+cat stdin.xy.dat | xpaset ds9 plot new name foo scatter stdin
+cat stdin.xyex.dat | xpaset ds9 plot new name foo scatter stdin
+cat stdin.xyey.dat | xpaset ds9 plot new name foo scatter stdin
+cat stdin.xyexey.dat | xpaset ds9 plot new name foo scatter stdin
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
 echo "..stdin text|error"
 cat stdin.error.dat | xpaset ds9 plot new stdin
 cat stdin.text.dat | xpaset ds9 plot new stdin
@@ -1314,6 +1445,18 @@ sleep "$delay"
 xpaset -p ds9 plot close
 xpaset -p ds9 plot close
 
+cat 4.dat | xpaset ds9 plot new bar "{The Title}" "{X Axis}" "{Y Axis}" 4
+cat 5.dat | xpaset ds9 plot new bar "{The Title}" "{X Axis}" "{Y Axis}" 5
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
+cat 4.dat | xpaset ds9 plot new scatter "{The Title}" "{X Axis}" "{Y Axis}" 4
+cat 5.dat | xpaset ds9 plot new scatter "{The Title}" "{X Axis}" "{Y Axis}" 5
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
 echo "..named 4|5"
 cat 4.dat | xpaset ds9 plot new name foo "{The Title}" "{X Axis}" "{Y Axis}" 4
 cat 5.dat | xpaset ds9 plot new name foo "{The Title}" "{X Axis}" "{Y Axis}" 5
@@ -1321,6 +1464,18 @@ sleep "$delay"
 xpaset -p ds9 plot close
 xpaset -p ds9 plot close
 
+cat 4.dat | xpaset ds9 plot new name foo bar "{The Title}" "{X Axis}" "{Y Axis}" 4
+cat 5.dat | xpaset ds9 plot new name foo bar "{The Title}" "{X Axis}" "{Y Axis}" 5
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
+cat 4.dat | xpaset ds9 plot new name foo scatter "{The Title}" "{X Axis}" "{Y Axis}" 4
+cat 5.dat | xpaset ds9 plot new name foo scatter "{The Title}" "{X Axis}" "{Y Axis}" 5
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
 echo "..xy|xyex|xyey|xyexey"
 cat xy.dat | xpaset ds9 plot new "{The Title}" "{X Axis}" "{Y Axis}" xy
 cat xyex.dat | xpaset ds9 plot new "{The Title}" "{X Axis}" "{Y Axis}" xyex
@@ -1332,6 +1487,26 @@ xpaset -p ds9 plot close
 xpaset -p ds9 plot close
 xpaset -p ds9 plot close
 
+cat xy.dat | xpaset ds9 plot new bar "{The Title}" "{X Axis}" "{Y Axis}" xy
+cat xyex.dat | xpaset ds9 plot new bar "{The Title}" "{X Axis}" "{Y Axis}" xyex
+cat xyey.dat | xpaset ds9 plot new bar "{The Title}" "{X Axis}" "{Y Axis}" xyey
+cat xyexey.dat | xpaset ds9 plot new bar "{The Title}" "{X Axis}" "{Y Axis}" xyexey
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
+cat xy.dat | xpaset ds9 plot new scatter "{The Title}" "{X Axis}" "{Y Axis}" xy
+cat xyex.dat | xpaset ds9 plot new scatter "{The Title}" "{X Axis}" "{Y Axis}" xyex
+cat xyey.dat | xpaset ds9 plot new scatter "{The Title}" "{X Axis}" "{Y Axis}" xyey
+cat xyexey.dat | xpaset ds9 plot new scatter "{The Title}" "{X Axis}" "{Y Axis}" xyexey
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
 echo "..name xy|xyex|xyey|xyexey"
 cat xy.dat | xpaset ds9 plot new name foo "{The Title}" "{X Axis}" "{Y Axis}" xy
 cat xyex.dat | xpaset ds9 plot new name foo "{The Title}" "{X Axis}" "{Y Axis}" xyex
@@ -1343,6 +1518,26 @@ xpaset -p ds9 plot close
 xpaset -p ds9 plot close
 xpaset -p ds9 plot close
 
+cat xy.dat | xpaset ds9 plot new name foo bar "{The Title}" "{X Axis}" "{Y Axis}" xy
+cat xyex.dat | xpaset ds9 plot new name foo bar "{The Title}" "{X Axis}" "{Y Axis}" xyex
+cat xyey.dat | xpaset ds9 plot new name foo bar "{The Title}" "{X Axis}" "{Y Axis}" xyey
+cat xyexey.dat | xpaset ds9 plot new name foo bar "{The Title}" "{X Axis}" "{Y Axis}" xyexey
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
+cat xy.dat | xpaset ds9 plot new name foo scatter "{The Title}" "{X Axis}" "{Y Axis}" xy
+cat xyex.dat | xpaset ds9 plot new name foo scatter "{The Title}" "{X Axis}" "{Y Axis}" xyex
+cat xyey.dat | xpaset ds9 plot new name foo scatter "{The Title}" "{X Axis}" "{Y Axis}" xyey
+cat xyexey.dat | xpaset ds9 plot new name foo scatter "{The Title}" "{X Axis}" "{Y Axis}" xyexey
+sleep "$delay"
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+xpaset -p ds9 plot close
+
 echo "..data"
 xpaset -p ds9 plot new name foo
 xpaset -p ds9 plot new
@@ -1383,14 +1578,21 @@ rm -f foo.ps
 
 echo "..grid"
 xpaset -p ds9 plot new
-xpaset -p ds9 plot graph grid yes
-xpaset -p ds9 plot graph scale loglog
-xpaset -p ds9 plot graph range x auto no
+xpaset -p ds9 plot load xy.dat xy
+xpaset -p ds9 plot graph grid x no
+xpaset -p ds9 plot graph grid y yes
+xpaset -p ds9 plot graph log x no
+xpaset -p ds9 plot graph log y no
+xpaset -p ds9 plot graph flip x no
+xpaset -p ds9 plot graph flip y no
 xpaset -p ds9 plot graph range x min 1
 xpaset -p ds9 plot graph range x max 100
-xpaset -p ds9 plot graph range y auto no
 xpaset -p ds9 plot graph range y min 1
 xpaset -p ds9 plot graph range y max 100
+xpaset -p ds9 plot graph range x auto yes
+xpaset -p ds9 plot graph range y auto yes
+xpaset -p ds9 plot graph format x {}
+xpaset -p ds9 plot graph format y {}
 xpaset -p ds9 plot graph labels title "{The Title}"
 xpaset -p ds9 plot graph labels xaxis "{X Axis}"
 xpaset -p ds9 plot graph labels yaxis "{Y Axis}"
@@ -1423,10 +1625,11 @@ xpaset -p ds9 plot view quadratic yes
 xpaset -p ds9 plot view errorbar yes
 
 xpaset -p ds9 plot color discrete red
-xpaset -p ds9 plot view line green
-xpaset -p ds9 plot view step blue
-xpaset -p ds9 plot view quadratic cyan
-xpaset -p ds9 plot view errorbar yellow
+xpaset -p ds9 plot color line green
+xpaset -p ds9 plot color step blue
+xpaset -p ds9 plot color quadratic cyan
+xpaset -p ds9 plot color errorbar yellow
+xpaset -p ds9 plot color errorbar magenta
 
 xpaset -p ds9 plot line discrete cross
 xpaset -p ds9 plot line line width 2
@@ -1654,7 +1857,7 @@ testit $tt
 rm -f foo.fits
 fi
 
-if [ "$1" = "saveimage" ]; then
+if [ "$1" = "saveimage" -o -z "$1" ]; then
 tt="saveimage"
 xpaset -p ds9 saveimage foo.fits
 xpaset -p ds9 saveimage foo.gif
@@ -1800,6 +2003,9 @@ xpaset -p ds9 smooth
 xpaset -p ds9 smooth yes
 xpaset -p ds9 smooth function tophat
 xpaset -p ds9 smooth radius 5
+xpaset -p ds9 smooth match
+xpaset -p ds9 smooth lock yes
+xpaset -p ds9 smooth lock no
 xpaset -p ds9 smooth no
 xpaset -p ds9 smooth close
 testit $tt
@@ -1982,10 +2188,10 @@ fi
 
 if [ "$1" = "web" -o -z "$1" ]; then
 tt="web"
-xpaset -p ds9 web hea-www.harvard.edu/RD/ds9/
+xpaset -p ds9 web hea-www.harvard.edu/RD/ds9/acknowledgment.html
 sleep "$delay"
 xpaget ds9 web >> ${tt}.out
-xpaset -p ds9 web hea-www.harvard.edu/RD/ds9/beta.html
+xpaset -p ds9 web hea-www.harvard.edu/RD/ds9/helpdesk.html
 sleep "$delay"
 xpaset -p ds9 web hvweb click back
 sleep "$delay"
